@@ -32,7 +32,7 @@
 //**********************************************************************
 #ifndef CM_1_0
 #define CM_1_0          100
-#endif 
+#endif
 #ifndef CM_2_0
 #define CM_2_0          200
 #endif
@@ -68,7 +68,7 @@
 #endif
 
 //Legacy MACRO, will be removed later
-#ifndef __INTEL_MDF 
+#ifndef __INTEL_MDF
 #define __INTEL_MDF     (CM_7_2)
 #endif
 
@@ -103,7 +103,7 @@
 #define CM_MIN_SURF_HEIGHT  1
 #define CM_MIN_SURF_DEPTH   2
 
-#define CM_MAX_1D_SURF_WIDTH  0X40000000 // 2^30
+#define CM_MAX_1D_SURF_WIDTH    0x80000000 // 2^31 2 GB
 
 #define CM_MAX_2D_SURF_WIDTH    16384
 #define CM_MAX_2D_SURF_HEIGHT   16384
@@ -139,9 +139,13 @@
 #define CM_DEVICE_CONFIG_DISABLE_TASKFLUSHEDSEMAPHORE_MASK   (1<<CM_DEVICE_CONFIG_DISABLE_TASKFLUSHEDSEMAPHORE_OFFSET)
 #define CM_DEVICE_CREATE_OPTION_TASKFLUSHEDSEMAPHORE_DISABLE  1   //to disable the semaphore for task flushed
 #define CM_DEVICE_CONFIG_MIDTHREADPREEMPTION_OFFSET           22
-#define CM_DEVICE_CONFIG_MIDTHREADPREEMPTION_DISENABLE         (1 << CM_DEVICE_CONFIG_MIDTHREADPREEMPTION_OFFSET)    
+#define CM_DEVICE_CONFIG_MIDTHREADPREEMPTION_DISENABLE         (1 << CM_DEVICE_CONFIG_MIDTHREADPREEMPTION_OFFSET)
 #define CM_DEVICE_CONFIG_KERNEL_DEBUG_OFFSET                  23
 #define CM_DEVICE_CONFIG_KERNEL_DEBUG_ENABLE               (1 << CM_DEVICE_CONFIG_KERNEL_DEBUG_OFFSET)
+#define CM_DEVICE_CONFIG_VEBOX_OFFSET                      28
+#define CM_DEVICE_CONFIG_VEBOX_DISABLE                     (1 << CM_DEVICE_CONFIG_VEBOX_OFFSET)
+#define CM_DEVICE_CONFIG_GPUCOPY_OFFSET                    29
+#define CM_DEVICE_CONFIG_GPUCOPY_DISABLE                   (1 << CM_DEVICE_CONFIG_GPUCOPY_OFFSET)
 #define CM_DEVICE_CONFIG_FAST_PATH_OFFSET                  30
 #define CM_DEVICE_CONFIG_FAST_PATH_ENABLE                  (1 << CM_DEVICE_CONFIG_FAST_PATH_OFFSET)
 
@@ -182,6 +186,10 @@
 #define CM_SVM_ACCESS_FLAG_ATOMICS           (1 << 1)                            //Crosse IA/GT atomics supported SVM buffer, need CM_SVM_ACCESS_FLAG_FINE_GRAINED flag is set as well
 #define CM_SVM_ACCESS_FLAG_DEFAULT           CM_SVM_ACCESS_FLAG_COARSE_GRAINED   //default is coarse-grained SVM buffer
 
+#define CM_BUFFER_STATELESS_CREATE_OPTION_GFX_MEM 0
+#define CM_BUFFER_STATELESS_CREATE_OPTION_SYS_MEM 1
+#define CM_BUFFER_STATELESS_CREATE_OPTION_DEGAULT CM_BUFFER_STATELESS_CREATE_OPTION_GFX_MEM
+
 //**********************************************************************
 // OS-specific includings and types
 //**********************************************************************
@@ -247,7 +255,7 @@ typedef enum _CM_RETURN_CODE
     CM_KERNELPAYLOAD_PERTHREADARG_MUTEX_FAIL    = -49,
     CM_KERNELPAYLOAD_PERKERNELARG_MUTEX_FAIL    = -50,
     CM_KERNELPAYLOAD_SETTING_FAILURE            = -51,
-    CM_KERNELPAYLOAD_SURFACE_INVALID_BTINDEX    = -52, 
+    CM_KERNELPAYLOAD_SURFACE_INVALID_BTINDEX    = -52,
     CM_NOT_SET_KERNEL_ARGUMENT                  = -53,
     CM_GPUCOPY_INVALID_SURFACES                 = -54,
     CM_GPUCOPY_INVALID_SIZE                     = -55,
@@ -298,6 +306,10 @@ typedef enum _CM_RETURN_CODE
     CM_FAILED_TO_CREATE_CURBE_SURFACE           = -100,
     CM_INVALID_CAP_NAME                         = -101,
     CM_INVALID_PARAM_FOR_CREATE_QUEUE_EX        = -102,
+    CM_INVALID_CREATE_OPTION_FOR_BUFFER_STATELESS = -103,
+    CM_INVALID_KERNEL_ARG_POINTER                 = -104,
+    CM_LOAD_LIBRARY_FAILED                        = -105,
+    CM_NO_SUPPORTED_ADAPTER                       = -106,
 
     /*
      * RANGE <=-10000 FOR INTERNAL ERROR CODE
@@ -324,16 +336,12 @@ typedef enum _CM_PIXEL_TYPE
 
 enum GPU_PLATFORM{
     PLATFORM_INTEL_UNKNOWN     = 0,
-    PLATFORM_INTEL_SNB         = 1,
-    PLATFORM_INTEL_IVB         = 2,
-    PLATFORM_INTEL_HSW         = 3,
     PLATFORM_INTEL_BDW         = 4,
-    PLATFORM_INTEL_VLV         = 5,
-    PLATFORM_INTEL_CHV         = 6,
     PLATFORM_INTEL_SKL         = 7,
     PLATFORM_INTEL_BXT         = 8,
-    PLATFORM_INTEL_CNL         = 9,
     PLATFORM_INTEL_KBL         = 11,
+    PLATFORM_INTEL_ICLLP       = 13,
+    PLATFORM_INTEL_TGLLP       = 15,
     PLATFORM_INTEL_GLK         = 16,
     PLATFORM_INTEL_CFL         = 17,
 };
@@ -377,7 +385,8 @@ typedef enum _CM_DEVICE_CAP_NAME
     CAP_USER_DEFINED_THREAD_COUNT_PER_THREAD_GROUP,
     CAP_SURFACE2DUP_COUNT,
     CAP_PLATFORM_INFO,
-    CAP_MAX_BUFFER_SIZE
+    CAP_MAX_BUFFER_SIZE,
+    CAP_MAX_SUBDEV_COUNT //for app to retrieve the total count of sub devices
 } CM_DEVICE_CAP_NAME;
 
 typedef enum _CM_FASTCOPY_OPTION
@@ -453,6 +462,17 @@ enum MEMORY_OBJECT_CONTROL
     MEMORY_OBJECT_CONTROL_CNL_NO_CACHE,
     MEMORY_OBJECT_CONTROL_CNL_COUNT,
 
+    // Unified memory object control type for SKL+
+    MEMORY_OBJECT_CONTROL_DEFAULT = 0x0,
+    MEMORY_OBJECT_CONTROL_NO_L3,
+    MEMORY_OBJECT_CONTROL_NO_LLC_ELLC,
+    MEMORY_OBJECT_CONTROL_NO_LLC,
+    MEMORY_OBJECT_CONTROL_NO_ELLC,
+    MEMORY_OBJECT_CONTROL_NO_LLC_L3,
+    MEMORY_OBJECT_CONTROL_NO_ELLC_L3,
+    MEMORY_OBJECT_CONTROL_NO_CACHE,
+    MEMORY_OBJECT_CONTROL_L1_ENABLED,
+
     MEMORY_OBJECT_CONTROL_UNKNOWN = 0xff
 };
 
@@ -547,21 +567,20 @@ typedef enum _CM_ROTATION
     CM_ROTATION_270,               //!< Rotation 270 degrees
 } CM_ROTATION;
 
-// to define frame type for interlace frame support 
-typedef enum _CM_FRAME_TYPE 
-{ 
-    CM_FRAME,     // singe frame, not interlaced 
-    CM_TOP_FIELD,  
-    CM_BOTTOM_FIELD, 
-    MAX_FRAME_TYPE 
-} CM_FRAME_TYPE; 
+// to define frame type for interlace frame support
+typedef enum _CM_FRAME_TYPE
+{
+    CM_FRAME,     // singe frame, not interlaced
+    CM_TOP_FIELD,
+    CM_BOTTOM_FIELD,
+    MAX_FRAME_TYPE
+} CM_FRAME_TYPE;
 
 enum CM_QUEUE_TYPE
 {
     CM_QUEUE_TYPE_NONE = 0,
     CM_QUEUE_TYPE_RENDER = 1,
-    CM_QUEUE_TYPE_COMPUTE = 2,
-    CM_QUEUE_TYPE_VEBOX = 3
+    CM_QUEUE_TYPE_COMPUTE = 2
 };
 
 enum CM_QUEUE_SSEU_USAGE_HINT_TYPE
@@ -576,18 +595,18 @@ enum CM_QUEUE_SSEU_USAGE_HINT_TYPE
 typedef struct _CM_SAMPLER_STATE
 {
     CM_TEXTURE_FILTER_TYPE minFilterType;
-    CM_TEXTURE_FILTER_TYPE magFilterType;   
-    CM_TEXTURE_ADDRESS_TYPE addressU;   
-    CM_TEXTURE_ADDRESS_TYPE addressV;   
-    CM_TEXTURE_ADDRESS_TYPE addressW; 
+    CM_TEXTURE_FILTER_TYPE magFilterType;
+    CM_TEXTURE_ADDRESS_TYPE addressU;
+    CM_TEXTURE_ADDRESS_TYPE addressV;
+    CM_TEXTURE_ADDRESS_TYPE addressW;
 } CM_SAMPLER_STATE;
 
 typedef struct _CM_SAMPLER_STATE_EX
 {
     CM_TEXTURE_FILTER_TYPE minFilterType;
-    CM_TEXTURE_FILTER_TYPE magFilterType;   
-    CM_TEXTURE_ADDRESS_TYPE addressU;   
-    CM_TEXTURE_ADDRESS_TYPE addressV;   
+    CM_TEXTURE_FILTER_TYPE magFilterType;
+    CM_TEXTURE_ADDRESS_TYPE addressU;
+    CM_TEXTURE_ADDRESS_TYPE addressV;
     CM_TEXTURE_ADDRESS_TYPE addressW;
 
     CM_PIXEL_TYPE SurfaceFormat;
@@ -608,7 +627,7 @@ typedef struct _CM_SAMPLER_STATE_EX
         INT BorderColorBlueS;
         FLOAT BorderColorBlueF;
     };
-    
+
     union {
         DWORD BorderColorAlphaU;
         INT BorderColorAlphaS;
@@ -631,7 +650,7 @@ typedef struct _CM_DLL_FILE_VERSION
     WORD    wMANVERSION;
     WORD    wMANREVISION;
     WORD    wSUBREVISION;
-    WORD    wBUILD_NUMBER; 
+    WORD    wBUILD_NUMBER;
     //Version constructed as : "wMANVERSION.wMANREVISION.wSUBREVISION.wBUILD_NUMBER"
 } CM_DLL_FILE_VERSION, *PCM_DLL_FILE_VERSION;
 
@@ -678,19 +697,19 @@ struct L3ConfigRegisterValues
 
 //GT-PIN
 typedef struct _CM_SURFACE_DETAILS{
-    UINT        width; 
-    UINT        height; 
-    UINT        depth; 
-    CM_SURFACE_FORMAT   format; 
+    UINT        width;
+    UINT        height;
+    UINT        depth;
+    CM_SURFACE_FORMAT   format;
     UINT        planeIndex;
-    UINT        pitch; 
+    UINT        pitch;
     UINT        slicePitch;
     UINT        SurfaceBaseAddress;
     UINT8       TiledSurface;
     UINT8       TileWalk;
     UINT        XOffset;
-    UINT        YOffset; 
-    
+    UINT        YOffset;
+
 }CM_SURFACE_DETAILS;
 
 /*
@@ -725,7 +744,7 @@ typedef struct _CM_AVS_NONPIPLINED_STATE{
     BYTE maxDerivative4Pixels;
     BYTE maxDerivative8Pixels;
     BYTE transitionArea4Pixels;
-    BYTE transitionArea8Pixels;    
+    BYTE transitionArea8Pixels;
     CM_AVS_COEFF_TABLE Tbl0X[ CM_NUM_COEFF_ROWS_SKL ];
     CM_AVS_COEFF_TABLE Tbl0Y[ CM_NUM_COEFF_ROWS_SKL ];
     CM_AVS_COEFF_TABLE Tbl1X[ CM_NUM_COEFF_ROWS_SKL ];
@@ -741,7 +760,7 @@ typedef struct _CM_AVS_INTERNEL_NONPIPLINED_STATE{
     BYTE maxDerivative4Pixels;
     BYTE maxDerivative8Pixels;
     BYTE transitionArea4Pixels;
-    BYTE transitionArea8Pixels;    
+    BYTE transitionArea8Pixels;
     CM_AVS_INTERNEL_COEFF_TABLE Tbl0X[ CM_NUM_COEFF_ROWS_SKL ];
     CM_AVS_INTERNEL_COEFF_TABLE Tbl0Y[ CM_NUM_COEFF_ROWS_SKL ];
     CM_AVS_INTERNEL_COEFF_TABLE Tbl1X[ CM_NUM_COEFF_ROWS_SKL ];
@@ -751,7 +770,7 @@ typedef struct _CM_AVS_INTERNEL_NONPIPLINED_STATE{
 }CM_AVS_INTERNEL_NONPIPLINED_STATE;
 
 typedef struct _CM_AVS_STATE_MSG{
-    bool AVSTYPE; //true nearest, false adaptive    
+    bool AVSTYPE; //true nearest, false adaptive
     bool EightTapAFEnable; //HSW+
     bool BypassIEF; //ignored for BWL, moved to sampler8x8 payload.
     bool ShuffleOutputWriteback; //SKL mode only to be set when AVS msg sequence is 4x4 or 8x4
@@ -764,10 +783,10 @@ typedef struct _CM_AVS_STATE_MSG{
     unsigned char RegularWght;
     unsigned char NonEdgeWght;
     unsigned short wR3xCoefficient;
-    unsigned short wR3cCoefficient;  
+    unsigned short wR3cCoefficient;
     unsigned short wR5xCoefficient;
     unsigned short wR5cxCoefficient;
-    unsigned short wR5cCoefficient;    
+    unsigned short wR5cCoefficient;
     //For Non-piplined states
     unsigned short stateID;
     CM_AVS_NONPIPLINED_STATE * AvsState;
@@ -775,7 +794,7 @@ typedef struct _CM_AVS_STATE_MSG{
 
 struct CM_AVS_STATE_MSG_EX {
   CM_AVS_STATE_MSG_EX();
-  
+
   bool enable_all_channel_adaptive_filter;  // adaptive filter for all channels. validValues => [true..false]
   bool enable_rgb_adaptive_filter;          // adaptive filter for all channels. validValues => [true..false]
   bool enable_8_tap_adaptive_filter;        // enable 8-tap filter. validValues => [true..false]
@@ -817,10 +836,10 @@ struct CM_AVS_STATE_MSG_EX {
   BYTE global_noise_estimation; // validValues => [0..255]
   bool mr_boost;                // validValues => [true..false]
   BYTE mr_smooth_threshold;     // validValues => [0..3]
-  BYTE mr_threshold; 
+  BYTE mr_threshold;
   bool steepness_boost;         // validValues => [true..false]
   BYTE steepness_threshold;     // validValues => [0..15]
-  bool texture_coordinate_mode; // true: clamp, false: mirror. validValues => [true..false]  
+  bool texture_coordinate_mode; // true: clamp, false: mirror. validValues => [true..false]
   BYTE max_hue;                 // Rectangle half width. validValued => [0..63]
   BYTE max_saturation;          // Rectangle half length. validValued => [0..63]
   int angles;                   // validValued => [0..360]
@@ -878,7 +897,7 @@ typedef struct _CM_CONVOLVE_COEFF_TABLE{
     float   FilterCoeff_0_13;
     float   FilterCoeff_0_14;
     float   FilterCoeff_0_15;
-    float   FilterCoeff_0_16;    
+    float   FilterCoeff_0_16;
     float   FilterCoeff_0_17;
     float   FilterCoeff_0_18;
     float   FilterCoeff_0_19;
@@ -900,7 +919,7 @@ typedef struct _CM_CONVOLVE_STATE_MSG{
     bool CoeffSize; //true 16-bit, false 8-bit
     byte SclDwnValue; //Scale down value
     byte Width; //Kernel Width
-    byte Height; //Kernel Height   
+    byte Height; //Kernel Height
     //SKL mode
     bool isVertical32Mode;
     bool isHorizontal32Mode;
@@ -1002,7 +1021,7 @@ typedef struct _CM_MISC_STATE {
         };
     } DW7;
 } CM_MISC_STATE;
- 
+
 typedef struct _CM_MISC_STATE_MSG{
     //DWORD 0
     union{
@@ -1145,13 +1164,13 @@ typedef struct _CM_VEBOX_STATE
 typedef struct _CM_POWER_OPTION
 {
     USHORT nSlice;                      // set number of slice to use: 0(default number), 1, 2...
-    USHORT nSubSlice;                   // set number of subslice to use: 0(default number), 1, 2... 
+    USHORT nSubSlice;                   // set number of subslice to use: 0(default number), 1, 2...
     USHORT nEU;                         // set number of EU to use: 0(default number), 1, 2...
 } CM_POWER_OPTION, *PCM_POWER_OPTION;
 
 // to support new flag with current API
 // new flag/field could be add to the end of this structure
-// 
+//
 struct CM_FLAG {
     CM_FLAG();
     CM_ROTATION rotationFlag;
@@ -1160,7 +1179,8 @@ struct CM_FLAG {
 
 struct _CM_TASK_CONFIG {
     bool     turboBoostFlag     : 1;
-    uint32_t reserved_bits      :31;
+    bool     fusedEuDispatchFlag : 1;
+    uint32_t reserved_bits      :30;
     uint32_t reserved0;
     uint32_t reserved1;
     uint32_t reserved2;
@@ -1205,16 +1225,18 @@ typedef struct _CM_SURFACE2D_STATE_PARAM
     UINT reserved[4]; // for future usage
 } CM_SURFACE2D_STATE_PARAM;
 
-struct CM_QUEUE_CREATE_OPTION
+struct _CM_QUEUE_CREATE_OPTION
 {
-    CM_QUEUE_TYPE QueueType : 3;
-    bool RunAloneMode       : 1;
-    unsigned int IsMultipleContextCase  : 3;
-    bool UserGPUContext     : 1;
-    unsigned int GPUContext : 8; // user provided GPU CONTEXT in enum MOS_GPU_CONTEXT, this will override CM_QUEUE_TYPE if set
-    CM_QUEUE_SSEU_USAGE_HINT_TYPE SseuUsageHint : 3;
-    unsigned int Reserved2  : 13;
+    CM_QUEUE_TYPE                 QueueType               : 3;
+    bool                          RAMode                  : 1;
+    unsigned int                  Reserved0               : 3;
+    bool                          UserGPUContext          : 1; // Is the user-provided GPU Context already created externally
+    unsigned int                  GPUContext              : 8; // user-provided GPU Context ordinal
+    CM_QUEUE_SSEU_USAGE_HINT_TYPE SseuUsageHint           : 3;
+    unsigned int                  Reserved1               : 1;
+    unsigned int                  Reserved2               : 12;
 };
+#define CM_QUEUE_CREATE_OPTION _CM_QUEUE_CREATE_OPTION
 
 typedef enum _CM_CONDITIONAL_END_OPERATOR_CODE {
     MAD_GREATER_THAN_IDD = 0,
@@ -1232,10 +1254,10 @@ struct CM_CONDITIONAL_END_PARAM {
     bool  opLevel;
 };
 
-//**********************************************************************
-// Constants
-//**********************************************************************
-const CM_QUEUE_CREATE_OPTION CM_DEFAULT_QUEUE_CREATE_OPTION = { CM_QUEUE_TYPE_RENDER, false, 0, false, 0, CM_QUEUE_SSEU_USAGE_HINT_DEFAULT, 0 };
+struct CM_KERNEL_SYNC_CONFIG {
+    bool     dataCacheFlush   : 1; // true: cache will be flushed;
+    uint32_t reserved         : 31;
+};
 
 //**********************************************************************
 // Classes forward declarations
@@ -1249,8 +1271,10 @@ class CmProgram;
 class CmBuffer;
 class CmBufferUP;
 class CmBufferSVM;
+class CmBufferStateless;
 class CmSurface2D;
 class CmSurface2DUP;
+class CmSurface2DStateless;
 class CmSurface3D;
 class CmSampler;
 class CmThreadSpace;
@@ -1264,6 +1288,11 @@ class SamplerIndex;
 //**********************************************************************
 #include "cm_rt_extension.h"
 
+//**********************************************************************
+// Constants
+//**********************************************************************
+const CM_QUEUE_CREATE_OPTION CM_DEFAULT_QUEUE_CREATE_OPTION = { CM_QUEUE_TYPE_RENDER, false, 0, false, 0, CM_QUEUE_SSEU_USAGE_HINT_DEFAULT, 0, 0 };
+
 //**********************************************************************
 // Classes
 //**********************************************************************
@@ -1290,26 +1319,27 @@ protected:
 
 class CmKernel
 {
-public:       
+public:
     CM_RT_API virtual INT SetThreadCount(UINT count ) = 0;
     CM_RT_API virtual INT SetKernelArg(UINT index, size_t size, const void * pValue ) = 0;
     CM_RT_API virtual INT SetThreadArg(UINT threadId, UINT index, size_t size, const void * pValue ) = 0;
     CM_RT_API virtual INT SetStaticBuffer(UINT index, const void * pValue ) = 0;
     CM_RT_API virtual INT SetSurfaceBTI(SurfaceIndex* pSurface, UINT BTIndex) = 0;
     CM_RT_API virtual INT AssociateThreadSpace(CmThreadSpace* & pTS) = 0;
-    CM_RT_API virtual INT AssociateThreadGroupSpace(CmThreadGroupSpace* & pTGS) = 0; 
+    CM_RT_API virtual INT AssociateThreadGroupSpace(CmThreadGroupSpace* & pTGS) = 0;
     CM_RT_API virtual INT SetSamplerBTI(SamplerIndex* pSampler, UINT nIndex) = 0;
     CM_RT_API virtual INT DeAssociateThreadSpace(CmThreadSpace* & pTS) = 0;
     CM_RT_API virtual INT DeAssociateThreadGroupSpace(CmThreadGroupSpace* & pTGS) = 0;
     CM_RT_API virtual INT QuerySpillSize(unsigned int &spillSize) = 0;
-    CM_RT_API virtual INT GetIndexForCurbeData( UINT curbe_data_size, SurfaceIndex *pSurface ) = 0;
+    CM_RT_API virtual INT SetKernelArgPointer(UINT index, size_t size, const void *pValue) = 0;
+
 protected:
    ~CmKernel(){};
 };
 
 class CmTask
 {
-public:       
+public:
     CM_RT_API virtual INT AddKernel(CmKernel *pKernel) = 0;
     CM_RT_API virtual INT Reset(void) = 0;
     CM_RT_API virtual INT AddSync(void) = 0;
@@ -1317,14 +1347,16 @@ public:
     CM_RT_API virtual INT AddConditionalEnd(SurfaceIndex* pSurface, UINT offset, CM_CONDITIONAL_END_PARAM *pCondParam) = 0;
     CM_RT_API virtual INT SetProperty(const CM_TASK_CONFIG &taskConfig) = 0;
     CM_RT_API virtual INT AddKernelWithConfig( CmKernel *pKernel, const CM_EXECUTION_CONFIG *config ) = 0;
+    CM_RT_API virtual INT GetProperty(CM_TASK_CONFIG &taskConfig) = 0;
+    CM_RT_API virtual INT AddSyncEx(const CM_KERNEL_SYNC_CONFIG *config) = 0;
 protected:
    ~CmTask(){};
-}; 
+};
 
 class CmBuffer
 {
 public:
-    CM_RT_API virtual INT GetIndex( SurfaceIndex*& pIndex ) = 0; 
+    CM_RT_API virtual INT GetIndex( SurfaceIndex*& pIndex ) = 0;
     CM_RT_API virtual INT ReadSurface( unsigned char* pSysMem, CmEvent* pEvent, UINT64 sysMemSize = 0xFFFFFFFFFFFFFFFFULL ) = 0;
     CM_RT_API virtual INT WriteSurface( const unsigned char* pSysMem, CmEvent* pEvent, UINT64 sysMemSize = 0xFFFFFFFFFFFFFFFFULL ) = 0;
     CM_RT_API virtual INT InitSurface(const DWORD initValue, CmEvent* pEvent) = 0;
@@ -1337,7 +1369,7 @@ protected:
 class CmBufferUP
 {
 public:
-    CM_RT_API virtual INT GetIndex( SurfaceIndex*& pIndex ) = 0; 
+    CM_RT_API virtual INT GetIndex( SurfaceIndex*& pIndex ) = 0;
     CM_RT_API virtual INT SelectMemoryObjectControlSetting(MEMORY_OBJECT_CONTROL option) = 0;
 protected:
    ~CmBufferUP(){};
@@ -1346,26 +1378,55 @@ protected:
 class CmBufferSVM
 {
 public:
-    CM_RT_API virtual INT GetIndex( SurfaceIndex*& pIndex ) = 0; 
+    CM_RT_API virtual INT GetIndex( SurfaceIndex*& pIndex ) = 0;
     CM_RT_API virtual INT GetAddress( void * &pAddr) = 0;
 protected:
     ~CmBufferSVM(){};
 };
 
+class CmBufferStateless
+{
+public:
+    CM_RT_API virtual INT GetGfxAddress(uint64_t &gfxAddr) = 0;
+    CM_RT_API virtual INT GetSysAddress(void *&pSysAddr) = 0;
+    CM_RT_API virtual INT ReadSurface(unsigned char *pSysMem,
+                                      CmEvent *pEvent,
+                                      uint64_t sysMemSize = 0xFFFFFFFFFFFFFFFFULL) = 0;
+    CM_RT_API virtual INT WriteSurface(const unsigned char *pSysMem,
+                                       CmEvent *pEvent,
+                                       uint64_t sysMemSize = 0xFFFFFFFFFFFFFFFFULL) = 0;
+protected:
+    ~CmBufferStateless() {};
+};
+
 class CmSurface2DUP
 {
-public:    
-    CM_RT_API virtual INT GetIndex( SurfaceIndex*& pIndex ) = 0; 
+public:
+    CM_RT_API virtual INT GetIndex( SurfaceIndex*& pIndex ) = 0;
     CM_RT_API virtual INT SelectMemoryObjectControlSetting(MEMORY_OBJECT_CONTROL option) = 0;
-    CM_RT_API virtual INT SetProperty(CM_FRAME_TYPE frameType) = 0; 
+    CM_RT_API virtual INT SetProperty(CM_FRAME_TYPE frameType) = 0;
 protected:
     ~CmSurface2DUP(){};
 };
 
+class CmSurface2DStateless
+{
+public:
+    CM_RT_API virtual INT GetGfxAddress(uint64_t &gfxAddr) = 0;
+    CM_RT_API virtual INT ReadSurface(unsigned char *pSysMem,
+                                      CmEvent *pEvent,
+                                      uint64_t sysMemSize = 0xFFFFFFFFFFFFFFFFULL) = 0;
+    CM_RT_API virtual INT WriteSurface(const unsigned char *pSysMem,
+                                       CmEvent *pEvent,
+                                       uint64_t sysMemSize = 0xFFFFFFFFFFFFFFFFULL) = 0;
+protected:
+    ~CmSurface2DStateless(){};
+};
+
 class CmSurface3D
 {
-public:    
-    CM_RT_API virtual INT GetIndex( SurfaceIndex*& pIndex ) = 0; 
+public:
+    CM_RT_API virtual INT GetIndex( SurfaceIndex*& pIndex ) = 0;
     CM_RT_API virtual INT ReadSurface( unsigned char* pSysMem, CmEvent* pEvent, UINT64 sysMemSize = 0xFFFFFFFFFFFFFFFFULL ) = 0;
     CM_RT_API virtual INT WriteSurface( const unsigned char* pSysMem, CmEvent* pEvent, UINT64 sysMemSize = 0xFFFFFFFFFFFFFFFFULL ) = 0;
     CM_RT_API virtual INT InitSurface(const DWORD initValue, CmEvent* pEvent) = 0;
@@ -1435,11 +1496,11 @@ protected:
 
 class CmQueue
 {
-public:    
+public:
     CM_RT_API virtual INT Enqueue( CmTask* pTask, CmEvent* & pEvent, const CmThreadSpace* pTS = nullptr ) = 0;
-    CM_RT_API virtual INT DestroyEvent( CmEvent* & pEvent ) = 0; 
+    CM_RT_API virtual INT DestroyEvent( CmEvent* & pEvent ) = 0;
     CM_RT_API virtual INT EnqueueWithGroup( CmTask* pTask, CmEvent* & pEvent, const CmThreadGroupSpace* pTGS = nullptr )=0;
-    CM_RT_API virtual INT EnqueueCopyCPUToGPU( CmSurface2D* pSurface, const unsigned char* pSysMem, CmEvent* & pEvent ) = 0; 
+    CM_RT_API virtual INT EnqueueCopyCPUToGPU( CmSurface2D* pSurface, const unsigned char* pSysMem, CmEvent* & pEvent ) = 0;
     CM_RT_API virtual INT EnqueueCopyGPUToCPU( CmSurface2D* pSurface, unsigned char* pSysMem, CmEvent* & pEvent ) = 0;
     CM_RT_API virtual INT EnqueueInitSurface2D( CmSurface2D* pSurface, const DWORD initValue, CmEvent* &pEvent ) = 0;
     CM_RT_API virtual INT EnqueueCopyGPUToGPU( CmSurface2D* pOutputSurface, CmSurface2D* pInputSurface, UINT option, CmEvent* & pEvent ) = 0;
@@ -1450,7 +1511,7 @@ public:
 
     CM_RT_API virtual INT EnqueueCopyCPUToGPUFullStrideDup( CmSurface2D* pSurface, const unsigned char* pSysMem, const UINT widthStride, const UINT heightStride, const UINT option, CmEvent* & pEvent ) = 0;
     CM_RT_API virtual INT EnqueueCopyGPUToCPUFullStrideDup( CmSurface2D* pSurface, unsigned char* pSysMem, const UINT widthStride, const UINT heightStride, const UINT option, CmEvent* & pEvent ) = 0;
-    
+
     CM_RT_API virtual INT EnqueueWithHints( CmTask* pTask, CmEvent* & pEvent, UINT hints = 0) = 0;
     CM_RT_API virtual INT EnqueueVebox( CmVebox* pVebox, CmEvent* & pEvent ) = 0;
 
@@ -1461,6 +1522,12 @@ public:
     CM_RT_API virtual INT EnqueueWithGroupFast(CmTask *task,
                                   CmEvent *&event,
                                   const CmThreadGroupSpace *threadGroupSpace = nullptr) = 0;
+
+    CM_RT_API virtual int32_t EnqueueReadBuffer(CmBuffer* buffer, size_t offset, const unsigned char* sysMem, uint64_t sysMemSize, CmEvent* wait_event, CmEvent*& event, unsigned option) = 0;
+    CM_RT_API virtual int32_t EnqueueWriteBuffer(CmBuffer* buffer, size_t offset, const unsigned char* sysMem, uint64_t sysMemSize, CmEvent* wait_event, CmEvent*& event, unsigned option) = 0;
+
+    CM_RT_API virtual INT SetResidentGroupAndParallelThreadNum(uint32_t residentGroupNum, uint32_t parallelThreadNum) = 0;
+
 protected:
     ~CmQueue(){};
 };
@@ -1489,5 +1556,7 @@ EXTERN_C CM_RT_API const char* GetCmErrorString(int errCode);
 #include "cm_rt_g8.h"
 #include "cm_rt_g9.h"
 #include "cm_rt_g10.h"
+#include "cm_rt_g11.h"
+#include "cm_rt_g12_tgl.h"
 
 #endif //__CM_RT_H__
