@@ -38,11 +38,17 @@ namespace CMRT_UMD
 //| Purpose:    Create CM Buffer
 //| Returns:    Result of the operation
 //*-----------------------------------------------------------------------------
-int32_t CmBuffer_RT::Create( uint32_t index, uint32_t handle, uint32_t size, bool isCmCreated, CmSurfaceManager* surfaceManager, uint32_t bufferType, bool isCMRTAllocatedSVM, void  *sysMem, CmBuffer_RT* &surface, bool isConditionalBuffer, uint32_t comparisonValue, bool enableCompareMask )
+int32_t CmBuffer_RT::Create(uint32_t index, uint32_t handle, size_t size,
+                            bool isCmCreated, CmSurfaceManager *surfaceManager,
+                            uint32_t bufferType, bool isCMRTAllocatedSVM, void  *sysMem,
+                            CmBuffer_RT *&surface, bool isConditionalBuffer,
+                            uint32_t comparisonValue, uint64_t gfxMem, bool enableCompareMask)
 {
     int32_t result = CM_SUCCESS;
 
-    surface = new (std::nothrow) CmBuffer_RT( handle, size, isCmCreated, surfaceManager, bufferType, isCMRTAllocatedSVM, sysMem, isConditionalBuffer, comparisonValue, enableCompareMask);
+    surface = new (std::nothrow)CmBuffer_RT(handle, size, isCmCreated, surfaceManager, bufferType,
+                                            isCMRTAllocatedSVM, sysMem, isConditionalBuffer,
+                                            comparisonValue, gfxMem, enableCompareMask);
     if( surface )
     {
         result = surface->Initialize( index );
@@ -61,18 +67,21 @@ int32_t CmBuffer_RT::Create( uint32_t index, uint32_t handle, uint32_t size, boo
     return result;
 }
 
-CmBuffer_RT::CmBuffer_RT( uint32_t handle, uint32_t size, bool isCmCreated, CmSurfaceManager* surfaceManager, uint32_t bufferType, bool isCMRTAllocatedSVM, void  *sysMem, bool isConditionalBuffer, uint32_t comparisonValue, bool enableCompareMask ):
-    CmSurface( surfaceManager,isCmCreated ),
-    m_handle( handle ),
-    m_size( size ),
+CmBuffer_RT::CmBuffer_RT(uint32_t handle, size_t size, bool isCmCreated,
+                         CmSurfaceManager* surfaceManager, uint32_t bufferType,
+                         bool isCMRTAllocatedSVM, void  *sysMem, bool isConditionalBuffer,
+                         uint32_t comparisonValue, uint64_t gfxAddr, bool enableCompareMask ):
+    CmSurface(surfaceManager, isCmCreated),
+    m_handle(handle),
+    m_size(size),
     m_bufferType(bufferType),
-    m_sysMem( sysMem ),
-    m_isCMRTAllocatedSVMBuffer( isCMRTAllocatedSVM ),
-    m_isConditionalBuffer( isConditionalBuffer ),
-    m_comparisonValue( comparisonValue ),
-    m_enableCompareMask( enableCompareMask ),
+    m_sysMem(sysMem),
+    m_gfxMem(gfxAddr),
+    m_isCMRTAllocatedSVMBuffer(isCMRTAllocatedSVM),
+    m_isConditionalBuffer(isConditionalBuffer),
+    m_comparisonValue(comparisonValue),
+    m_enableCompareMask(enableCompareMask),
     m_numAliases(0)
-
 {
     CmSurface::SetMemoryObjectControl(MEMORY_OBJECT_CONTROL_UNKNOW, CM_USE_PTE, 0);
     CmSafeMemSet(m_aliasIndexes, 0, sizeof(SurfaceIndex*) * CM_HAL_MAX_NUM_BUFFER_ALIASES);
@@ -101,13 +110,13 @@ int32_t CmBuffer_RT::GetHandle( uint32_t& handle)
 //| Purpose:    Write data from sysMem to Buffer
 //| Returns:    Result of the operation
 //*-----------------------------------------------------------------------------
-CM_RT_API int32_t CmBuffer_RT::WriteSurface( const unsigned char* sysMem, CmEvent* event, uint64_t sysMemSize )
+int32_t CmBuffer_RT::WriteBuffer( const unsigned char* sysMem, CmEvent* event, uint64_t sysMemSize, size_t offset)
 {
     INSERT_API_CALL_LOG();
 
     CM_RETURN_CODE  hr      = CM_SUCCESS;
-    uint8_t         *dst    = nullptr;
-    uint8_t         *surf   = nullptr;
+    uint8_t *dst    = nullptr;
+    uint8_t *surf   = nullptr;
     size_t copySize = MOS_MIN((size_t)sysMemSize, m_size);
 
     if (sysMem == nullptr)
@@ -153,8 +162,8 @@ CM_RT_API int32_t CmBuffer_RT::WriteSurface( const unsigned char* sysMem, CmEven
     CM_CHK_MOSSTATUS_GOTOFINISH_CMERROR(cmData->cmHalState->pfnLockBuffer(cmData->cmHalState, &inParam));
     CM_CHK_NULL_GOTOFINISH_CMERROR(inParam.data);
 
-    // Memory copy : Source ->System Memory  Dest -> Vedio Memory
-    dst  = ( uint8_t *)(inParam.data);
+    // Memory copy : Source ->System Memory  Dest -> Video Memory
+    dst  = ( uint8_t *)(inParam.data) + offset;
     surf = ( uint8_t *)sysMem;
 
     CmFastMemCopyWC(dst, surf, copySize);
@@ -173,12 +182,13 @@ finish:
 //| Purpose:    Read data from sysMem to Buffer
 //| Returns:    Result of the operation
 //*-----------------------------------------------------------------------------
-CM_RT_API int32_t CmBuffer_RT::ReadSurface( unsigned char* sysMem, CmEvent* event, uint64_t sysMemSize )
+int32_t CmBuffer_RT::ReadBuffer( unsigned char* sysMem, CmEvent* event, uint64_t sysMemSize, size_t offset)
 {
     INSERT_API_CALL_LOG();
 
     CM_RETURN_CODE  hr          = CM_SUCCESS;
-
+    uint8_t* surf = nullptr;
+    uint8_t* dst = nullptr;
     size_t copySize = MOS_MIN((size_t)sysMemSize, m_size);
 
     if (sysMem == nullptr)
@@ -222,8 +232,12 @@ CM_RT_API int32_t CmBuffer_RT::ReadSurface( unsigned char* sysMem, CmEvent* even
     CM_CHK_NULL_GOTOFINISH_CMERROR(inParam.data);
 
     // Memory copy : Dest ->System Memory  Source -> Vedio Memory
-    CmFastMemCopyFromWC(sysMem, inParam.data, copySize, GetCpuInstructionLevel());
-
+    // CmFastMemCopyFromWC(sysMem, (void*)(&((unsigned char*)inParam.data)[offset]), copySize, GetCpuInstructionLevel());
+    // Memory copy : Source ->System Memory  Dest -> Video Memory
+    surf = (uint8_t *)(inParam.data) + offset;
+    dst = (uint8_t *)sysMem;
+    CmFastMemCopyFromWC(dst, surf, copySize, GetCpuInstructionLevel());
+    //MOS_SecureMemcpy(dst, copySize, surf, copySize);
     //Unlock Buffer
     CM_CHK_MOSSTATUS_GOTOFINISH_CMERROR(cmData->cmHalState->pfnUnlockBuffer(cmData->cmHalState, &inParam));
 
@@ -240,6 +254,145 @@ CM_RT_API int32_t CmBuffer_RT::GetIndex( SurfaceIndex*& index )
     return CM_SUCCESS;
 }
 
+
+//*-----------------------------------------------------------------------------
+//| Purpose:    Write data from sysMem to Buffer
+//| Returns:    Result of the operation
+//*-----------------------------------------------------------------------------
+CM_RT_API int32_t CmBuffer_RT::WriteSurface(const unsigned char* sysMem, CmEvent* event, uint64_t sysMemSize)
+{
+    INSERT_API_CALL_LOG();
+
+    CM_RETURN_CODE  hr = CM_SUCCESS;
+    uint8_t* dst = nullptr;
+    uint8_t* surf = nullptr;
+    size_t copySize = MOS_MIN((size_t)sysMemSize, m_size);
+
+    if (sysMem == nullptr)
+    {
+        CM_ASSERTMESSAGE("Error: Pointer to system memory is null.");
+        return CM_NULL_POINTER;
+    }
+
+    // It makes sense to flush the whole enqueued tasks for each surface read
+    // because usually we read the output of the last task.
+    // Update: using event not to flush the whole enqueued tasks
+    if (event)
+    {
+        CmEventRT* eventRT = dynamic_cast<CmEventRT*>(event);
+        if (eventRT)
+        {
+            FlushDeviceQueue(eventRT);
+        }
+        else
+        {
+            event->WaitForTaskFinished();
+        }
+    }
+
+    WaitForReferenceFree(); // wait all owner task finished
+
+    // Lock Buffer first
+    CmDeviceRT* cmDevice = nullptr;
+    m_surfaceMgr->GetCmDevice(cmDevice);
+    CM_CHK_NULL_RETURN_CMERROR(cmDevice);
+
+    PCM_CONTEXT_DATA cmData = (PCM_CONTEXT_DATA)cmDevice->GetAccelData();
+    CM_CHK_NULL_RETURN_CMERROR(cmData);
+    CM_CHK_NULL_RETURN_CMERROR(cmData->cmHalState);
+
+    CM_HAL_BUFFER_PARAM inParam;
+    CmSafeMemSet(&inParam, 0, sizeof(CM_HAL_BUFFER_PARAM));
+    inParam.lockFlag = CM_HAL_LOCKFLAG_WRITEONLY;
+    inParam.handle = m_handle;
+
+    // Lock Buffer:
+    // Lock Buffer may fail due to the out of memory/out of page-in in KMD.
+    CM_CHK_MOSSTATUS_GOTOFINISH_CMERROR(cmData->cmHalState->pfnLockBuffer(cmData->cmHalState, &inParam));
+    CM_CHK_NULL_GOTOFINISH_CMERROR(inParam.data);
+
+    // Memory copy : Source ->System Memory  Dest -> Vedio Memory
+    dst = (uint8_t*)(inParam.data);
+    surf = (uint8_t*)sysMem;
+
+    CmFastMemCopyWC(dst, surf, copySize);
+
+    //Unlock Buffer
+    CM_CHK_MOSSTATUS_GOTOFINISH_CMERROR(cmData->cmHalState->pfnUnlockBuffer(cmData->cmHalState, &inParam));
+
+finish:
+    if (hr < CM_MOS_STATUS_CONVERTED_CODE_OFFSET) {
+        hr = CM_LOCK_SURFACE_FAIL;
+    }
+    return hr;
+}
+
+//*-----------------------------------------------------------------------------
+//| Purpose:    Read data from sysMem to Buffer
+//| Returns:    Result of the operation
+//*-----------------------------------------------------------------------------
+CM_RT_API int32_t CmBuffer_RT::ReadSurface(unsigned char* sysMem, CmEvent* event, uint64_t sysMemSize)
+{
+    INSERT_API_CALL_LOG();
+
+    CM_RETURN_CODE  hr = CM_SUCCESS;
+
+    size_t copySize = MOS_MIN((size_t)sysMemSize, m_size);
+
+    if (sysMem == nullptr)
+    {
+        CM_ASSERTMESSAGE("Error: Pointer to system memory is null.");
+        return CM_NULL_POINTER;
+    }
+
+    // It makes sense to flush the whole enqueued tasks for each surface read
+    // because usually we read the output of the last task.
+    // Update: using event not to flush the whole enqueued tasks
+    if (event)
+    {
+        CmEventRT* eventRT = dynamic_cast<CmEventRT*>(event);
+        if (eventRT)
+        {
+            FlushDeviceQueue(eventRT);
+        }
+        else
+        {
+            event->WaitForTaskFinished();
+        }
+    }
+
+    WaitForReferenceFree();    // wait all owner task finished
+
+    // Lock Buffer first
+    CmDeviceRT* cmDevice = nullptr;
+    m_surfaceMgr->GetCmDevice(cmDevice);
+    CM_CHK_NULL_RETURN_CMERROR(cmDevice);
+    PCM_CONTEXT_DATA cmData = (PCM_CONTEXT_DATA)cmDevice->GetAccelData();
+    CM_CHK_NULL_RETURN_CMERROR(cmData);
+    CM_CHK_NULL_RETURN_CMERROR(cmData->cmHalState);
+
+    CM_HAL_BUFFER_PARAM inParam;
+    CmSafeMemSet(&inParam, 0, sizeof(CM_HAL_BUFFER_PARAM));
+    inParam.lockFlag = CM_HAL_LOCKFLAG_READONLY;
+    inParam.handle = m_handle;
+
+    CM_CHK_MOSSTATUS_GOTOFINISH_CMERROR(cmData->cmHalState->pfnLockBuffer(cmData->cmHalState, &inParam));
+    CM_CHK_NULL_GOTOFINISH_CMERROR(inParam.data);
+
+    // Memory copy : Dest ->System Memory  Source -> Vedio Memory
+    CmFastMemCopyFromWC(sysMem, inParam.data, copySize, GetCpuInstructionLevel());
+
+    //Unlock Buffer
+    CM_CHK_MOSSTATUS_GOTOFINISH_CMERROR(cmData->cmHalState->pfnUnlockBuffer(cmData->cmHalState, &inParam));
+
+finish:
+    if (hr < CM_MOS_STATUS_CONVERTED_CODE_OFFSET) {
+        hr = CM_LOCK_SURFACE_FAIL;
+    }
+    return hr;
+}
+
+
 CM_RT_API int32_t CmBuffer_RT::InitSurface(const uint32_t initValue, CmEvent* event)
 {
     INSERT_API_CALL_LOG();
@@ -292,12 +445,10 @@ finish:
 
 int32_t CmBuffer_RT::SetMemoryObjectControl( MEMORY_OBJECT_CONTROL memCtrl, MEMORY_TYPE memType, uint32_t age)
 {
-    INSERT_API_CALL_LOG();
 
-    CM_RETURN_CODE  hr = CM_SUCCESS;
+    int32_t  hr = CM_SUCCESS;
     uint16_t mocs = 0;
-
-    CmSurface::SetMemoryObjectControl( memCtrl, memType, age );
+    hr = CmSurface::SetMemoryObjectControl( memCtrl, memType, age );
 
     CmDeviceRT *cmDevice = nullptr;
     m_surfaceMgr->GetCmDevice(cmDevice);
@@ -307,22 +458,44 @@ int32_t CmBuffer_RT::SetMemoryObjectControl( MEMORY_OBJECT_CONTROL memCtrl, MEMO
     CM_CHK_NULL_RETURN_CMERROR(cmData->cmHalState);
 
     mocs = (m_memObjCtrl.mem_ctrl << 8) | (m_memObjCtrl.mem_type<<4) | m_memObjCtrl.age;
-
     CM_CHK_MOSSTATUS_GOTOFINISH_CMERROR(cmData->cmHalState->pfnSetSurfaceMOCS(cmData->cmHalState, m_handle, mocs, ARG_KIND_SURFACE_1D));
-
+    ++ m_propertyIndex;
 finish:
     return hr;
 }
 
 CM_RT_API int32_t CmBuffer_RT::SelectMemoryObjectControlSetting(MEMORY_OBJECT_CONTROL memCtrl)
 {
+    INSERT_API_CALL_LOG();
+    ++ m_propertyIndex;
     return SetMemoryObjectControl(memCtrl, CM_USE_PTE, 0);
 }
 
+CMRT_UMD_API int32_t CmBuffer_RT::SetResourceUsage(const MOS_HW_RESOURCE_DEF mosUsage)
+{
+    INSERT_API_CALL_LOG();
+    int32_t  hr = CM_SUCCESS;
+    uint16_t mocs = 0;
+    hr = CmSurface::SetResourceUsage(mosUsage);
+
+    CmDeviceRT *cmDevice = nullptr;
+    m_surfaceMgr->GetCmDevice(cmDevice);
+    CM_CHK_NULL_RETURN_CMERROR(cmDevice);
+    PCM_CONTEXT_DATA cmData = (PCM_CONTEXT_DATA)cmDevice->GetAccelData();
+    CM_CHK_NULL_RETURN_CMERROR(cmData);
+    CM_CHK_NULL_RETURN_CMERROR(cmData->cmHalState);
+
+    mocs = (m_memObjCtrl.mem_ctrl << 8) | (m_memObjCtrl.mem_type << 4) | m_memObjCtrl.age;
+    CM_CHK_MOSSTATUS_GOTOFINISH_CMERROR(cmData->cmHalState->pfnSetSurfaceMOCS(cmData->cmHalState, m_handle, mocs, ARG_KIND_SURFACE_1D));
+    ++ m_propertyIndex;
+finish:
+    return hr;
+}
+
 CM_RT_API int32_t CmBuffer_RT::SetSurfaceStateParam(SurfaceIndex *surfIndex, const CM_BUFFER_STATE_PARAM *bufferStateParam)
 {
-    CM_RETURN_CODE  hr          = CM_SUCCESS;
-    uint32_t        newSize    = 0;
+    CM_RETURN_CODE hr = CM_SUCCESS;
+    size_t newSize = 0;
     if(bufferStateParam->uiBaseAddressOffset + bufferStateParam->uiSize > m_size)
     {
         CM_ASSERTMESSAGE("Error: The offset exceeds the buffer size.");
@@ -367,21 +540,15 @@ CM_RT_API int32_t CmBuffer_RT::SetSurfaceStateParam(SurfaceIndex *surfIndex, con
     inParam.mocs    = (uint16_t)((bufferStateParam->mocs.mem_ctrl << 8)|(bufferStateParam->mocs.mem_type << 4)|(bufferStateParam->mocs.age));
 
     CM_CHK_MOSSTATUS_GOTOFINISH_CMERROR(cmData->cmHalState->pfnSetBufferSurfaceStatePara(cmData->cmHalState, &inParam));
+    ++ m_propertyIndex;
 
 finish:
     return hr;
 }
 
-int32_t CmBuffer_RT::GetSize( uint32_t& size )
-{
-    size = m_size;
-    return CM_SUCCESS;
-}
-
-int32_t CmBuffer_RT::SetSize( uint32_t size )
+void CmBuffer_RT::SetSize( size_t size )
 {
     m_size = size;
-    return CM_SUCCESS;
 }
 
 bool CmBuffer_RT::IsUpSurface()
@@ -474,18 +641,19 @@ void CmBuffer_RT::Log(std::ostringstream &oss)
 //| Returns:    None
 //| Notes:      Must be called after task finished.
 //*-----------------------------------------------------------------------------
-void CmBuffer_RT::DumpContent(uint32_t kernelNumber, char *kernelName, int32_t taskId, uint32_t argIndex)
+void CmBuffer_RT::DumpContent(uint32_t kernelNumber, char *kernelName, int32_t taskId, uint32_t argIndex, uint32_t vectorIndex)
 {
 #if MDF_SURFACE_CONTENT_DUMP
     std::ostringstream outputFileName;
     static uint32_t bufferDumpNumber = 0;
-    char               fileNamePrefix[MAX_PATH];
+    char               fileNamePrefix[MAX_PATH] = {0};
     std::ofstream      outputFileStream;
 
     outputFileName << "t_" << taskId
         << "_k_" << kernelNumber
         << "_" << kernelName
         <<"_argi_"<< argIndex
+        <<"_vector_index_"<< vectorIndex
         << "_buffer_surfi_" << m_index->get_data()
         <<"_w_"<< m_size
         <<"_"<< bufferDumpNumber;
@@ -493,7 +661,7 @@ void CmBuffer_RT::DumpContent(uint32_t kernelNumber, char *kernelName, int32_t t
     GetLogFileLocation(outputFileName.str().c_str(), fileNamePrefix);
 
     // Open file
-    outputFileStream.open(fileNamePrefix, std::ios::app);
+    outputFileStream.open(fileNamePrefix, std::ios::app | std::ios::binary);
     CM_ASSERT(outputFileStream);
 
     if (m_sysMem != nullptr)
@@ -546,4 +714,16 @@ int32_t CmBuffer_RT::UpdateProperty(uint32_t size)
     m_size = size;
     return CM_SUCCESS;
 }
-}
\ No newline at end of file
+
+CM_RT_API int32_t CmBuffer_RT::GetGfxAddress(uint64_t &gfxAddr)
+{
+    gfxAddr = m_gfxMem;
+    return CM_SUCCESS;
+}
+
+CM_RT_API int32_t CmBuffer_RT::GetSysAddress(void *&sysAddr)
+{
+    sysAddr = m_sysMem;
+    return CM_SUCCESS;
+}
+}
