@@ -160,7 +160,10 @@ typedef enum _CM_RETURN_CODE
     CM_FAILED_TO_CREATE_CURBE_SURFACE           = -100,
     CM_INVALID_CAP_NAME                         = -101,
     CM_INVALID_USER_GPU_CONTEXT_FOR_QUEUE_EX    = -102,
-
+    CM_INVALID_CREATE_OPTION_FOR_BUFFER_STATELESS = -103,
+    CM_INVALID_KERNEL_ARG_POINTER                 = -104,
+    CM_SYSTEM_MEMORY_NOT_2PIXELS_ALIGNED          = -105,
+    CM_NO_SUPPORTED_ADAPTER                       = -106,
     /*
      * RANGE -10000 ~ -19999 FOR INTERNAL ERROR CODE
      */
@@ -172,8 +175,6 @@ typedef enum _CM_RETURN_CODE
     CM_MOS_STATUS_CONVERTED_CODE_OFFSET         = -20000
 } CM_RETURN_CODE;
 
-#define VPHAL_CM_MAX_THREADS    "CmMaxThreads"
-
 //------------------------------------------------------------------------------
 //| Lock flags
 //------------------------------------------------------------------------------
@@ -342,6 +343,12 @@ typedef enum _CM_RETURN_CODE
 #define CM_DEVICE_CONFIG_KERNEL_DEBUG_OFFSET                23
 #define CM_DEVICE_CONFIG_KERNEL_DEBUG_ENABLE               (1 << CM_DEVICE_CONFIG_KERNEL_DEBUG_OFFSET)
 
+#define CM_DEVICE_CONFIG_VEBOX_OFFSET                       28
+#define CM_DEVICE_CONFIG_VEBOX_DISABLE                      (1 << CM_DEVICE_CONFIG_VEBOX_OFFSET)
+
+#define CM_DEVICE_CONFIG_GPUCOPY_OFFSET                     29
+#define CM_DEVICE_CONFIG_GPUCOPY_DISABLE                    (1 << CM_DEVICE_CONFIG_GPUCOPY_OFFSET)
+
 #define CM_DEVICE_CONFIG_FAST_PATH_OFFSET                   30
 #define CM_DEVICE_CONFIG_FAST_PATH_ENABLE                   (1 << CM_DEVICE_CONFIG_FAST_PATH_OFFSET)
 
@@ -397,6 +404,10 @@ typedef enum _CM_RETURN_CODE
 
 #define CM_VERSION (CM_DDI_7_2)
 
+#define CM_BUFFER_STATELESS_CREATE_OPTION_GFX_MEM 0
+#define CM_BUFFER_STATELESS_CREATE_OPTION_SYS_MEM 1
+#define CM_BUFFER_STATELESS_CREATE_OPTION_DEFAULT CM_BUFFER_STATELESS_CREATE_OPTION_GFX_MEM
+
 //------------------------------------------------------------------------------
 //| Forward declarations
 //------------------------------------------------------------------------------
@@ -410,8 +421,7 @@ enum CM_QUEUE_TYPE
 {
     CM_QUEUE_TYPE_NONE = 0,
     CM_QUEUE_TYPE_RENDER = 1,
-    CM_QUEUE_TYPE_COMPUTE = 2,
-    CM_QUEUE_TYPE_VEBOX = 3
+    CM_QUEUE_TYPE_COMPUTE = 2
 };
 
 enum CM_QUEUE_SSEU_USAGE_HINT_TYPE
@@ -420,18 +430,20 @@ enum CM_QUEUE_SSEU_USAGE_HINT_TYPE
     CM_QUEUE_SSEU_USAGE_HINT_VME  = 1
 };
 
-struct CM_QUEUE_CREATE_OPTION
+struct _CM_QUEUE_CREATE_OPTION
 {
-    CM_QUEUE_TYPE QueueType : 3;
-    bool RunAloneMode       : 1;
-    unsigned int Reserved0  : 3;
-    bool UserGPUContext     : 1;
-    unsigned int GPUContext : 8; // user provided GPU CONTEXT in enum MOS_GPU_CONTEXT, this will override CM_QUEUE_TYPE if set
-    CM_QUEUE_SSEU_USAGE_HINT_TYPE SseuUsageHint : 3;
-    unsigned int Reserved2  : 13;
+    CM_QUEUE_TYPE                 QueueType               : 3;
+    bool                          RAMode                  : 1;
+    unsigned int                  Reserved0               : 3;
+    bool                          UserGPUContext          : 1; // Is the user-provided GPU Context already created externally
+    unsigned int                  GPUContext              : 8; // user-provided GPU Context ordinal
+    CM_QUEUE_SSEU_USAGE_HINT_TYPE SseuUsageHint           : 3;
+    unsigned int                  Reserved1               : 1;
+    unsigned int                  Reserved2               : 12;
 };
+#define CM_QUEUE_CREATE_OPTION _CM_QUEUE_CREATE_OPTION
 
-const CM_QUEUE_CREATE_OPTION CM_DEFAULT_QUEUE_CREATE_OPTION = { CM_QUEUE_TYPE_RENDER, false, 0, false, 0, CM_QUEUE_SSEU_USAGE_HINT_DEFAULT, 0 };
+const CM_QUEUE_CREATE_OPTION CM_DEFAULT_QUEUE_CREATE_OPTION = { CM_QUEUE_TYPE_RENDER, false, 0, false, 0, CM_QUEUE_SSEU_USAGE_HINT_DEFAULT, 0, 0 };
 
 //------------------------------------------------------------------------------
 //|GT-PIN
@@ -519,8 +531,9 @@ typedef struct _CM_WALKING_PARAMETERS
 
 typedef struct _CM_TASK_CONFIG
 {
-    bool     turboBoostFlag     : 1;
-    uint32_t reserved_bits      :31;
+    bool     turboBoostFlag      : 1;
+    bool     fusedEuDispatchFlag : 1;
+    uint32_t reserved_bits       :30;
     uint32_t reserved0;
     uint32_t reserved1;
     uint32_t reserved2;
@@ -538,6 +551,11 @@ struct CM_EXECUTION_CONFIG
     int                 concurrentPolicy    = 0; //Reserve for future extension.
 };
 
+struct CM_KERNEL_SYNC_CONFIG {
+    bool     dataCacheFlush   : 1; // true: cache will be flushed;
+    uint32_t reserved         : 31;
+};
+
 struct L3ConfigRegisterValues
 {
     unsigned int config_register0;
