@@ -68,8 +68,6 @@ static uint32_t HalCm_CopyHexDwordLine(char  *destBuf, size_t buflen, uint32_t *
 //!           flag to control if need time stamp
 //! \param    [in] counter
 //!           dump file counter
-//! \param    [in] pValueName
-//!           pointer to value name, used for user feature read
 //! \param    [in] outputDir
 //!           pointer to output dir
 //! \param    [in] outputFile
@@ -77,7 +75,7 @@ static uint32_t HalCm_CopyHexDwordLine(char  *destBuf, size_t buflen, uint32_t *
 //! \return   number of bytes written
 //!
 int32_t GetFileNameAndCounter(char fileNamePrefix[], bool timeStampFlag, int32_t counter,
-                              const char *pValueName, const char *outputDir,const char *outputFile)
+                              const char *outputDir,const char *outputFile)
 {
     GetLogFileLocation(outputDir, fileNamePrefix);
     PlatformSNPrintf(fileNamePrefix + strlen(fileNamePrefix), 
@@ -97,17 +95,17 @@ int32_t GetFileNameAndCounter(char fileNamePrefix[], bool timeStampFlag, int32_t
         //check if command buffer or surface state counter, and get it
         if (!strcmp(outputFile,"Command_Buffer"))
         {
-            counter = GetCommandBufferDumpCounter(__MEDIA_USER_FEATURE_VALUE_MDF_CMD_DUMP_COUNTER);
+            counter = GetCommandBufferDumpCounter(__MEDIA_USER_FEATURE_VALUE_MDF_CMD_DUMP_COUNTER_ID);
         }
         else if (!strcmp(outputFile,"Surface_State_Dump"))
         {
-            counter = GetSurfaceStateDumpCounter(__MEDIA_USER_FEATURE_VALUE_MDF_SURFACE_STATE_DUMP_COUNTER);
+            counter = GetSurfaceStateDumpCounter(__MEDIA_USER_FEATURE_VALUE_MDF_SURFACE_STATE_DUMP_COUNTER_ID);
         }
         else if (!strcmp(outputFile, "Interface_Descriptor_Data_Dump"))
         {
-            counter = GetInterfaceDescriptorDataDumpCounter(__MEDIA_USER_FEATURE_VALUE_MDF_INTERFACE_DESCRIPTOR_DATA_COUNTER);
+            counter = GetInterfaceDescriptorDataDumpCounter(__MEDIA_USER_FEATURE_VALUE_MDF_INTERFACE_DESCRIPTOR_DATA_COUNTER_ID);
         }
-       
+
         PlatformSNPrintf(fileNamePrefix + strlen(fileNamePrefix), 
                          MOS_MAX_HLT_FILENAME_LEN - strlen(fileNamePrefix), "%s_%d.txt", outputFile, counter);
     }
@@ -130,39 +128,29 @@ int32_t GetFileNameAndCounter(char fileNamePrefix[], bool timeStampFlag, int32_t
 //!
 int32_t HalCm_InitDumpCommandBuffer(PCM_HAL_STATE state)
 {
-    MOS_USER_FEATURE        userFeature;
-    char                    fileName[MOS_MAX_HLT_FILENAME_LEN];
-    MOS_STATUS              eStatus;
-    MOS_USER_FEATURE_VALUE  userFeatureValue;
-    int32_t                 hr = CM_FAILURE;
+    char                            fileName[MOS_MAX_HLT_FILENAME_LEN];
+    MOS_STATUS                      eStatus;
+    MOS_USER_FEATURE_VALUE_DATA     userFeatureValueData;
+    int32_t                         hr = CM_FAILURE;
 
     MOS_OS_ASSERT(state);
 
-    MOS_ZeroMemory(&userFeatureValue, sizeof(MOS_USER_FEATURE_VALUE));
-    MOS_ZeroMemory(&userFeature, sizeof(userFeature));
+    MOS_ZeroMemory(&userFeatureValueData, sizeof(userFeatureValueData));
 
     // Check if command buffer dump was enabled in user feature settings.
-    userFeature.Type = MOS_USER_FEATURE_TYPE_USER;
-    userFeature.pPath = __MEDIA_USER_FEATURE_SUBKEY_INTERNAL;
-    userFeature.pValues = &userFeatureValue;
-    userFeature.uiNumValues = 1;
-    userFeatureValue.bData = false;
-
     GetLogFileLocation(HALCM_COMMAND_BUFFER_OUTPUT_DIR, fileName);
 
-    eStatus = MOS_UserFeature_ReadValue(
+    eStatus = MOS_UserFeature_ReadValue_ID(
         nullptr,
-        &userFeature,
-        "Dump Command Buffer Enable",
-        MOS_USER_FEATURE_VALUE_TYPE_INT32);
+        __MEDIA_USER_FEATURE_VALUE_MDF_CMD_DUMP_ENABLE_ID,
+        &userFeatureValueData);
     if (eStatus != MOS_STATUS_SUCCESS)
     {
         MOS_OS_NORMALMESSAGE("Unable to read command buffer user feature key. Status = %d", eStatus);
         goto finish;
     }
-    if (userFeatureValue.bData)
+    if (userFeatureValueData.bData)
     {
-       
         eStatus = MOS_CreateDirectory(fileName);
         if (eStatus != MOS_STATUS_SUCCESS)
         {
@@ -170,8 +158,8 @@ int32_t HalCm_InitDumpCommandBuffer(PCM_HAL_STATE state)
             goto finish;
         }
         // Setup member function and variable.
-        state->dumpCommandBuffer = userFeatureValue.bData?true: false;
-        if (userFeatureValue.bData == 17)
+        state->dumpCommandBuffer = userFeatureValueData.bData ? true : false;
+        if (userFeatureValueData.bData == 17)
         {
             state->enableCMDDumpTimeStamp = true;
         }
@@ -221,7 +209,6 @@ int32_t HalCm_DumpCommadBuffer(PCM_HAL_STATE state, PMOS_COMMAND_BUFFER cmdBuffe
    //Check if use timestamp in cmd buffer dump file
     commandBufferNumber = GetFileNameAndCounter(fileName, state->enableCMDDumpTimeStamp,
                           commandBufferNumber,
-                          __MEDIA_USER_FEATURE_VALUE_MDF_CMD_DUMP_COUNTER, 
                           HALCM_COMMAND_BUFFER_OUTPUT_DIR,
                           HALCM_COMMAND_BUFFER_OUTPUT_FILE);
 
@@ -277,35 +264,26 @@ finish:
 //!
 int32_t HalCm_InitDumpCurbeData(PCM_HAL_STATE state)
 {
-    MOS_USER_FEATURE        userFeature;
-    char                    fileName[MOS_MAX_HLT_FILENAME_LEN];
-    MOS_STATUS              eStatus;
-    MOS_USER_FEATURE_VALUE  userFeatureValue;
-    int32_t                 hr = CM_FAILURE;
+    MOS_USER_FEATURE_VALUE_DATA userFeatureValueData;
+    char                        fileName[MOS_MAX_HLT_FILENAME_LEN];
+    MOS_STATUS                  eStatus;
+    int32_t                     hr = CM_FAILURE;
 
     MOS_OS_ASSERT(state);
 
-    MOS_ZeroMemory(&userFeatureValue, sizeof(MOS_USER_FEATURE_VALUE));
-    MOS_ZeroMemory(&userFeature, sizeof(userFeature));
+    MOS_ZeroMemory(&userFeatureValueData, sizeof(userFeatureValueData));
 
     // Check if curbe data dump was enabled in user feature settings.
-    userFeature.Type = MOS_USER_FEATURE_TYPE_USER;
-    userFeature.pPath = __MEDIA_USER_FEATURE_SUBKEY_INTERNAL;
-    userFeature.pValues = &userFeatureValue;
-    userFeature.uiNumValues = 1;
-    userFeatureValue.bData = false;
-
-    eStatus = MOS_UserFeature_ReadValue(
+    eStatus = MOS_UserFeature_ReadValue_ID(
         nullptr,
-        &userFeature,
-        __MEDIA_USER_FEATURE_VALUE_MDF_CURBE_DUMP_ENABLE,
-        MOS_USER_FEATURE_VALUE_TYPE_INT32);
+        __MEDIA_USER_FEATURE_VALUE_MDF_CURBE_DUMP_ENABLE_ID,
+        &userFeatureValueData);
     if (eStatus != MOS_STATUS_SUCCESS)
     {
         MOS_OS_NORMALMESSAGE("Unable to read curbe data dump user feature key. Status = %d", eStatus);
         goto finish;
     }
-    if (userFeatureValue.bData)
+    if (userFeatureValueData.bData)
     {
         GetLogFileLocation(HALCM_CURBE_DATA_OUTPUT_DIR, fileName);
         eStatus = MOS_CreateDirectory(fileName);
@@ -315,7 +293,7 @@ int32_t HalCm_InitDumpCurbeData(PCM_HAL_STATE state)
             goto finish;
         }
         // Setup member function and variable.
-        state->dumpCurbeData = userFeatureValue.bData ? true: false;
+        state->dumpCurbeData = userFeatureValueData.bData ? true : false;
     }
     hr = CM_SUCCESS;
 finish:
@@ -414,37 +392,28 @@ finish:
 //!
 int32_t HalCm_InitSurfaceDump(PCM_HAL_STATE state)
 {
-    MOS_USER_FEATURE        userFeature;
-    MOS_STATUS              eStatus;
-    MOS_USER_FEATURE_VALUE  userFeatureValue;
-    int32_t                 hr = CM_FAILURE;
+    MOS_USER_FEATURE_VALUE_DATA userFeatureValueData;
+    MOS_STATUS                  eStatus;
+    int32_t                     hr = CM_FAILURE;
 
     MOS_OS_ASSERT(state);
 
-    MOS_ZeroMemory(&userFeatureValue, sizeof(MOS_USER_FEATURE_VALUE));
-    MOS_ZeroMemory(&userFeature, sizeof(userFeature));
+    MOS_ZeroMemory(&userFeatureValueData, sizeof(userFeatureValueData));
 
     // Check if surface content dump was enabled in user feature settings.
-    userFeature.Type = MOS_USER_FEATURE_TYPE_USER;
-    userFeature.pPath = __MEDIA_USER_FEATURE_SUBKEY_INTERNAL;
-    userFeature.pValues = &userFeatureValue;
-    userFeature.uiNumValues = 1;
-    userFeatureValue.bData = false;
-
-    eStatus = MOS_UserFeature_ReadValue(
+    eStatus = MOS_UserFeature_ReadValue_ID(
         nullptr,
-        &userFeature,
-        __MEDIA_USER_FEATURE_VALUE_MDF_SURFACE_DUMP_ENABLE,
-        MOS_USER_FEATURE_VALUE_TYPE_INT32);
+        __MEDIA_USER_FEATURE_VALUE_MDF_SURFACE_DUMP_ENABLE_ID,
+        &userFeatureValueData);
     if (eStatus != MOS_STATUS_SUCCESS)
     {
         MOS_OS_NORMALMESSAGE("Unable to read surface content dump user feature key. Status = %d", eStatus);
         goto finish;
     }
-    if (userFeatureValue.bData)
+    if (userFeatureValueData.bData)
     {
         // Setup member function and variable.
-        state->dumpSurfaceContent = userFeatureValue.bData ? true: false;
+        state->dumpSurfaceContent = userFeatureValueData.bData ? true : false;
     }
     hr = CM_SUCCESS;
 finish:
@@ -460,37 +429,28 @@ finish:
 
 int32_t HalCm_InitDumpSurfaceState(PCM_HAL_STATE state)
 {
-    MOS_USER_FEATURE        userFeature;
-    char                    fileName[MOS_MAX_HLT_FILENAME_LEN];
-    MOS_STATUS              eStatus;
-    MOS_USER_FEATURE_VALUE  userFeatureValue;
-    int32_t                 hr = CM_FAILURE;
+    MOS_USER_FEATURE_VALUE_DATA userFeatureValueData;
+    char                        fileName[MOS_MAX_HLT_FILENAME_LEN];
+    MOS_STATUS                  eStatus;
+    int32_t                     hr = CM_FAILURE;
 
     MOS_OS_ASSERT(state);
 
-    MOS_ZeroMemory(&userFeatureValue, sizeof(MOS_USER_FEATURE_VALUE));
-    MOS_ZeroMemory(&userFeature, sizeof(userFeature));
+    MOS_ZeroMemory(&userFeatureValueData, sizeof(userFeatureValueData));
 
     // Check if command buffer dump was enabled in user feature settings.
-    userFeature.Type = MOS_USER_FEATURE_TYPE_USER;
-    userFeature.pPath = __MEDIA_USER_FEATURE_SUBKEY_INTERNAL;
-    userFeature.pValues = &userFeatureValue;
-    userFeature.uiNumValues = 1;
-    userFeatureValue.bData = false;
-
     GetLogFileLocation(HALCM_SURFACE_STATE_OUTPUT_DIR, fileName);
 
-    eStatus = MOS_UserFeature_ReadValue(
+    eStatus = MOS_UserFeature_ReadValue_ID(
         nullptr,
-        &userFeature,
-        __MEDIA_USER_FEATURE_VALUE_MDF_SURFACE_STATE_DUMP_ENABLE,
-        MOS_USER_FEATURE_VALUE_TYPE_INT32);
+        __MEDIA_USER_FEATURE_VALUE_MDF_SURFACE_STATE_DUMP_ENABLE_ID,
+        &userFeatureValueData);
     if (eStatus != MOS_STATUS_SUCCESS)
     {
         MOS_OS_NORMALMESSAGE("Unable to read surface state user feature key. Status = %d", eStatus);
         goto finish;
     }
-    if (userFeatureValue.bData)
+    if (userFeatureValueData.bData)
     {
         eStatus = MOS_CreateDirectory(fileName);
         if (eStatus != MOS_STATUS_SUCCESS)
@@ -499,9 +459,9 @@ int32_t HalCm_InitDumpSurfaceState(PCM_HAL_STATE state)
             goto finish;
         }
         // Setup member function and variable.
-        state->dumpSurfaceState = userFeatureValue.bData ? true : false;
+        state->dumpSurfaceState = userFeatureValueData.bData ? true : false;
 
-        if (userFeatureValue.bData == 17)
+        if (userFeatureValueData.bData == 17)
         {
             state->enableSurfaceStateDumpTimeStamp = true;
         }
@@ -543,7 +503,6 @@ int32_t HalCm_DumpSurfaceState(PCM_HAL_STATE state,  int offsetSurfaceState, siz
    //Check if use timestamp in cmd buffer dump file
     surfacestatedumpNumber = GetFileNameAndCounter(filename, state->enableSurfaceStateDumpTimeStamp,
         surfacestatedumpNumber,
-        __MEDIA_USER_FEATURE_VALUE_MDF_SURFACE_STATE_DUMP_COUNTER,
         HALCM_SURFACE_STATE_OUTPUT_DIR,
         HALCM_SURFACE_STATE_OUTPUT_FILE);
     
@@ -601,37 +560,28 @@ finish:
 
 int32_t HalCm_InitDumpInterfaceDescriporData(PCM_HAL_STATE state)
 {
-    MOS_USER_FEATURE        userFeature;
-    char                    fileName[MOS_MAX_HLT_FILENAME_LEN];
-    MOS_STATUS              eStatus;
-    MOS_USER_FEATURE_VALUE  userFeatureValue;
-    int32_t                 hr = CM_FAILURE;
+    MOS_USER_FEATURE_VALUE_DATA userFeatureValueData;
+    char                        fileName[MOS_MAX_HLT_FILENAME_LEN];
+    MOS_STATUS                  eStatus;
+    int32_t                     hr = CM_FAILURE;
 
     MOS_OS_ASSERT(state);
 
-    MOS_ZeroMemory(&userFeatureValue, sizeof(MOS_USER_FEATURE_VALUE));
-    MOS_ZeroMemory(&userFeature, sizeof(userFeature));
+    MOS_ZeroMemory(&userFeatureValueData, sizeof(userFeatureValueData));
 
     // Check if command buffer dump was enabled in user feature settings.
-    userFeature.Type = MOS_USER_FEATURE_TYPE_USER;
-    userFeature.pPath = __MEDIA_USER_FEATURE_SUBKEY_INTERNAL;
-    userFeature.pValues = &userFeatureValue;
-    userFeature.uiNumValues = 1;
-    userFeatureValue.bData = false;
-
     GetLogFileLocation(HALCM_INTERFACE_DESCRIPTOR_DATA_OUTPUT_DIR, fileName);
 
-    eStatus = MOS_UserFeature_ReadValue(
+    eStatus = MOS_UserFeature_ReadValue_ID(
         nullptr,
-        &userFeature,
-        __MEDIA_USER_FEATURE_VALUE_MDF_INTERFACE_DESCRIPTOR_DATA_DUMP,
-        MOS_USER_FEATURE_VALUE_TYPE_INT32);
+        __MEDIA_USER_FEATURE_VALUE_MDF_INTERFACE_DESCRIPTOR_DATA_DUMP_ID,
+        &userFeatureValueData);
     if (eStatus != MOS_STATUS_SUCCESS)
     {
         MOS_OS_NORMALMESSAGE("Unable to read interface descriptor data dump user feature key. Status = %d", eStatus);
         goto finish;
     }
-    if (userFeatureValue.bData)
+    if (userFeatureValueData.bData)
     {
         eStatus = MOS_CreateDirectory(fileName);
         if (eStatus != MOS_STATUS_SUCCESS)
@@ -640,8 +590,8 @@ int32_t HalCm_InitDumpInterfaceDescriporData(PCM_HAL_STATE state)
             goto finish;
         }
         // Setup member function and variable.
-        state->dumpIDData = userFeatureValue.bData ? true : false;
-        if (userFeatureValue.bData == 17)
+        state->dumpIDData = userFeatureValueData.bData ? true : false;
+        if (userFeatureValueData.bData == 17)
         {
             state->enableIDDumpTimeStamp = true;
         }
@@ -685,7 +635,6 @@ int32_t HalCm_DumpInterfaceDescriptorData(PCM_HAL_STATE state)
     //Check if use timestamp in cmd buffer dump file
     IDDNumber = GetFileNameAndCounter(fileName, state->enableIDDumpTimeStamp,
         IDDNumber,
-        __MEDIA_USER_FEATURE_VALUE_MDF_SURFACE_STATE_DUMP_COUNTER,
         HALCM_INTERFACE_DESCRIPTOR_DATA_OUTPUT_DIR,
         HALCM_INTERFACE_DESCRIPTOR_DATA_OUTPUT_FILE);
 
