@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017, Intel Corporation
+* Copyright (c) 2017-2019, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -36,65 +36,68 @@
 
 namespace CodechalDbgAttr
 {
-static const char *attrPicParams             = "PicParams";
-static const char *attrSubsetsParams         = "SubsetsParams";
-static const char *attrFeiPicParams          = "FeiPicParams";
-static const char *attrMvcExtPicParams       = "MvcExtPicParams";
-static const char *attrSegmentParams         = "SegmentParams";
-static const char *attrSlcParams             = "SlcParams";
-static const char *attrMbParams              = "MbParams";
-static const char *attrIqParams              = "IqParams";
-static const char *attrSeqParams             = "SeqParams";
-static const char *attrVuiParams             = "VuiParams";
-static const char *attrBitstream             = "Bitstream";
-static const char *attrStreamOut             = "StreamOut";
-static const char *attrStreamIn              = "StreamIn";
-static const char *attrResidualDifference    = "ResidualDifference";
-static const char *attrDeblocking            = "Deblocking";
-static const char *attrMvData                = "MvData";
-static const char *attrVc1Bitplane           = "Vc1Bitplane";
-static const char *attrCoefProb              = "CoefProb";
-static const char *attrSegId                 = "SegId";
-static const char *attrHucRegions            = "HucRegions";
-static const char *attrHuCDmem               = "HucDmem";
-static const char *attrCmdBufferMfx          = "CmdBufferMfx";
-static const char *attr2ndLvlBatchMfx        = "2ndLvlBatchMfx";
-static const char *attrDecodeOutputSurface   = "DecodeOutputSurface";
-static const char *attrDecodeAuxSurface      = "DumpAuxsurface";
-static const char *attrSfcOutputSurface      = "SfcOutputSurface";
-static const char *attrReferenceSurfaces     = "ReferenceSurfaces";
-static const char *attrEncodeRawInputSurface = "EncodeRawInputSurface";
-static const char *attrReconstructedSurface  = "ReconstructedSurface";
-static const char *attrPakInput              = "PakInput";
-static const char *attrPakOutput             = "PakOutput";
-static const char *attrUpsamlingInput        = "UpsamplingInput";
-static const char *attrResidualSurface       = "ResidualSurface";
-static const char *attrStCoeff               = "StCoeff";
-static const char *attrCoeffPredCs           = "CoeffPredCs";
-static const char *attrMbRecord              = "MbRecord";
-static const char *attrOverwriteCommands     = "OverwriteCommands";
-static const char *attrHuffmanTbl            = "HuffmanTbl";
-static const char *attrScanParams            = "ScanParams";
-static const char *attrDriverUltDump         = "DriverUltDump";
-static const char *attrDumpBufferInBinary    = "DumpBufferInBinary";
-static const char *attrDumpToThreadFolder    = "DumpToThreadFolder";
-static const char *attrDumpCmdBufInBinary    = "DumpCmdBufInBinary";
-static const char *attrDumpEncodePar         = "DumpEncodePar";
-static const char *attrForceCmdDumpLvl       = "ForceCmdDumpLvl";
-static const char *attrForceCurbeDumpLvl     = "ForceCurbeDumpLvl";
-static const char *attrVdencOutput           = "VdencOutput";
-static const char *attrDecodeProcParams      = "DecodeProcParams";
-static const char *attrFrameState            = "FrameState";
-static const char *attrCUStreamout           = "CUStreamout";
-static const char *attrBrcPakStats           = "BrcPakStats";
-static const char *attrImageState            = "ImageState";
-static const char *attrSliceSizeStreamout    = "SliceSizeStreamout";
-static const char *attrCoeffProb             = "PakHwCoeffProbs";
-static const char *attrStatusReport          = "StatusReport";
-static const char *attrPakObjStreamout       = "PakObjStreamOut";
-static const char *attrTileBasedStats        = "TileBasedStats";
-static const char *attrROISurface            = "ROIInput";
-static const char *attrHuCStitchDataBuf      = "HuCStitchDataBuffer";
+static const char *attrPicParams              = "PicParams";
+static const char *attrSubsetsParams          = "SubsetsParams";
+static const char *attrFeiPicParams           = "FeiPicParams";
+static const char *attrMvcExtPicParams        = "MvcExtPicParams";
+static const char *attrSegmentParams          = "SegmentParams";
+static const char *attrSlcParams              = "SlcParams";
+static const char *attrMbParams               = "MbParams";
+static const char *attrIqParams               = "IqParams";
+static const char *attrSeqParams              = "SeqParams";
+static const char *attrVuiParams              = "VuiParams";
+static const char *attrBitstream              = "Bitstream";
+static const char *attrStreamOut              = "StreamOut";
+static const char *attrStreamIn               = "StreamIn";
+static const char *attrResidualDifference     = "ResidualDifference";
+static const char *attrDeblocking             = "Deblocking";
+static const char *attrMvData                 = "MvData";
+static const char *attrVc1Bitplane            = "Vc1Bitplane";
+static const char *attrCoefProb               = "CoefProb";
+static const char *attrSegId                  = "SegId";
+static const char *attrHucRegions             = "HucRegions";
+static const char *attrHuCDmem                = "HucDmem";
+static const char *attrCmdBufferMfx           = "CmdBufferMfx";
+static const char *attr2ndLvlBatchMfx         = "2ndLvlBatchMfx";
+static const char *attrDecodeOutputSurface    = "DecodeOutputSurface";
+static const char *attrDecodeAuxSurface       = "DumpAuxsurface";
+static const char *attrDecodeBltOutput        = "DumpBltOutput";
+static const char *attrSfcOutputSurface       = "SfcOutputSurface";
+static const char *attrReferenceSurfaces      = "ReferenceSurfaces";
+static const char *attrEncodeRawInputSurface  = "EncodeRawInputSurface";
+static const char *attrReconstructedSurface   = "ReconstructedSurface";
+static const char *attrPakInput               = "PakInput";
+static const char *attrPakOutput              = "PakOutput";
+static const char *attrUpsamlingInput         = "UpsamplingInput";
+static const char *attrResidualSurface        = "ResidualSurface";
+static const char *attrStCoeff                = "StCoeff";
+static const char *attrCoeffPredCs            = "CoeffPredCs";
+static const char *attrMbRecord               = "MbRecord";
+static const char *attrOverwriteCommands      = "OverwriteCommands";
+static const char *attrHuffmanTbl             = "HuffmanTbl";
+static const char *attrScanParams             = "ScanParams";
+static const char *attrDriverUltDump          = "DriverUltDump";
+static const char *attrDumpBufferInBinary     = "DumpBufferInBinary";
+static const char *attrDumpToThreadFolder     = "DumpToThreadFolder";
+static const char *attrDumpCmdBufInBinary     = "DumpCmdBufInBinary";
+static const char *attrDumpEncodePar          = "DumpEncodePar";
+static const char *attrForceCmdDumpLvl        = "ForceCmdDumpLvl";
+static const char *attrForceCurbeDumpLvl      = "ForceCurbeDumpLvl";
+static const char *attrForceYUVDumpWithMemcpy = "ForceYUVDumpWithMemcpy";
+static const char *attrDisableSwizzleForDumps = "DisableSwizzleForDumps";
+static const char *attrVdencOutput            = "VdencOutput";
+static const char *attrDecodeProcParams       = "DecodeProcParams";
+static const char *attrFrameState             = "FrameState";
+static const char *attrCUStreamout            = "CUStreamout";
+static const char *attrBrcPakStats            = "BrcPakStats";
+static const char *attrImageState             = "ImageState";
+static const char *attrSliceSizeStreamout     = "SliceSizeStreamout";
+static const char *attrCoeffProb              = "PakHwCoeffProbs";
+static const char *attrStatusReport           = "StatusReport";
+static const char *attrPakObjStreamout        = "PakObjStreamOut";
+static const char *attrTileBasedStats         = "TileBasedStats";
+static const char *attrROISurface             = "ROIInput";
+static const char *attrHuCStitchDataBuf       = "HuCStitchDataBuffer";
 
 // MD5 attributes
 static const char *attrMD5HashEnable    = "MD5HasEnable";
