@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2011-2017, Intel Corporation
+* Copyright (c) 2011-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -42,6 +42,7 @@
 
 #include "media_interfaces_mhw.h"
 
+#include "gfxmacro.h"
 //------------------------------------------------------------------------------
 // Macros specific to MOS_CODEC_SUBCOMP_HW sub-comp
 //------------------------------------------------------------------------------
@@ -941,6 +942,23 @@ public:
         uint32_t                   *commandsSize,
         uint32_t                   *patchListSize);
 
+    //!
+    //! \brief    Calculates maximum size for all slice level VDEnc commands
+    //! \details  Client facing function to calculate the maximum size for Vdenc slice level commands
+    //! \param    [in] mode
+    //!           Indicate the codec mode
+    //! \param    [out] commandsSize
+    //!           The maximum command buffer size
+    //! \param    [out] patchListSize
+    //!           The maximum command patch list size
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    MOS_STATUS GetVdencPrimitiveCommandsDataSize(
+        uint32_t                    mode,
+        uint32_t                   *commandsSize,
+        uint32_t                   *patchListSize);
+
     //!
     //! \brief    Calculates the maximum size for Vdenc picture 2nd level commands
     //! \details  Client facing function to calculate the maximum size for Vdenc picture 2nd level commands
