@@ -178,7 +178,8 @@ MediaMemDecompState::~MediaMemDecompState()
 }
 
 MediaMemDecompState::MediaMemDecompState() :
-    MediaMemDecompBaseState()
+    MediaMemDecompBaseState(),
+    m_currCmdBufId(0)
 {
     MHW_FUNCTION_ENTER;
     m_stateHeapSettings.m_ishBehavior = HeapManager::Behavior::clientControlled;
@@ -694,6 +695,8 @@ MOS_STATUS MediaMemDecompState::GetResourceInfo(
     surface->dwDepth                     = details.dwDepth;
     surface->bArraySpacing               = details.bArraySpacing;
     surface->TileType                    = details.TileType;
+    surface->TileModeGMM                 = details.TileModeGMM;
+    surface->bGMMTileEnabled             = details.bGMMTileEnabled;
     surface->dwOffset                    = details.RenderOffset.YUV.Y.BaseOffset;
     surface->UPlaneOffset.iSurfaceOffset = details.RenderOffset.YUV.U.BaseOffset;
     surface->UPlaneOffset.iXOffset       = details.RenderOffset.YUV.U.XOffset;
