@@ -135,6 +135,9 @@ typedef struct _MHW_STATE_BASE_ADDR_PARAMS
     uint32_t                mocs4GeneralState;
     uint32_t                mocs4DynamicState;
     uint32_t                mocs4SurfaceState;
+    uint32_t                mocs4IndirectObjectBuffer;
+    uint32_t                mocs4StatelessDataport;
+    uint32_t                l1CacheConfig;
 } MHW_STATE_BASE_ADDR_PARAMS, *PMHW_STATE_BASE_ADDR_PARAMS;
 
 typedef struct _MHW_VFE_SCOREBOARD_DELTA
@@ -264,7 +267,6 @@ typedef struct _MHW_WALKER_PARAMS
 
     bool                    bAddMediaFlush;
     bool                    bRequestSingleSlice;
-    bool                    bForceNoneCpWorkload;
 
     uint32_t                IndirectDataLength;
     uint32_t                IndirectDataStartAddress;
@@ -368,6 +370,28 @@ public:
         PMOS_COMMAND_BUFFER             cmdBuffer,
         PMHW_VFE_PARAMS                 params) = 0;
 
+    //!
+    //! \brief    Adds CFE_STATE to the command buffer
+    //! \param    cmdBuffer
+    //!           [in] Command buffer to which HW command is added
+    //! \param    params
+    //!           [in] Params structure used to populate the HW command
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    virtual MOS_STATUS AddCfeStateCmd(
+        PMOS_COMMAND_BUFFER             cmdBuffer,
+        PMHW_VFE_PARAMS                 params)
+    {
+        MOS_UNUSED(cmdBuffer);
+        MOS_UNUSED(params);
+
+        // CFE_STATE will replace the MEDIA_VFE_STATE on some platform; Just keep the
+        // platform which really uses CFE to implement it on inheriting class .
+        MHW_ASSERTMESSAGE("Don't support it on this platform");
+        return MOS_STATUS_SUCCESS;
+    }
+
     //!
     //! \brief    Adds MEDIA_CURBE_LOAD to the command buffer
     //! \param    cmdBuffer
@@ -557,6 +581,14 @@ public:
     //!
     void SetOsInterface(PMOS_INTERFACE osInterface) { m_osInterface = osInterface;}
 
+    //!
+    //! \brief    Get mmio registers address
+    //! \details  Get mmio registers address
+    //! \return   [out] PMHW_MI_MMIOREGISTERS*
+    //!           mmio registers got.
+    //!
+    virtual PMHW_MI_MMIOREGISTERS GetMmioRegisters() = 0;
+
 protected:
     //!
     //! \brief    Initializes the Render interface
