@@ -372,7 +372,9 @@ enum MHW_MEDIASTATE_SURFACEFORMAT
     MHW_MEDIASTATE_SURFACEFORMAT_B8G8R8A8_UNORM     = 14,   // sample_8x8 only
     MHW_MEDIASTATE_SURFACEFORMAT_R16G16B16A16       = 15,   // Sample_8x8 only
     MHW_MEDIASTATE_SURFACEFORMAT_PLANAR_420_16      = 23,   // Sample_8x8 only
-    MHW_MEDIASTATE_SURFACEFORMAT_R16B16_UNORM       = 24    // Sample_8x8 only
+    MHW_MEDIASTATE_SURFACEFORMAT_R16B16_UNORM       = 24,   // Sample_8x8 only
+    MHW_MEDIASTATE_SURFACEFORMAT_R16_UNORM          = 25,   // Sample_8x8 only
+    MHW_MEDIASTATE_SURFACEFORMAT_Y16_UNORM          = 26    // Sample_8x8 only
 };
 
 enum GFX3DSTATE_SURFACETYPE
@@ -382,6 +384,8 @@ enum GFX3DSTATE_SURFACETYPE
     GFX3DSTATE_SURFACETYPE_3D      = 2,
     GFX3DSTATE_SURFACETYPE_CUBE    = 3,
     GFX3DSTATE_SURFACETYPE_BUFFER  = 4,
+    GFX3DSTATE_SURFACETYPE_SREBUF  = 5,  // Structured buffer surface.
+    GFX3DSTATE_SURFACETYPE_SCRATCH = 6,  // Scratch space buffer.
     GFX3DSTATE_SURFACETYPE_NULL    = 7
 };
 
@@ -580,6 +584,12 @@ typedef struct _MHW_BATCH_BUFFER_LIST
     uint32_t                dwSize;                         //!< Total BB memory in this list
 } MHW_BATCH_BUFFER_LIST,*PMHW_BATCH_BUFFER_LIST;
 
+enum WRITE_FLAG
+{
+    WRITE     = 0x1,
+    WRITE_WA  = 0x2,
+};
+
 typedef struct _MHW_RESOURCE_PARAMS
 {
     PMOS_RESOURCE                       presResource;
@@ -597,7 +607,7 @@ typedef struct _MHW_RESOURCE_PARAMS
 
     MOS_HW_COMMAND                      HwCommandType;
     uint32_t                            dwSharedMocsOffset;
-    bool                                bIsWritable;
+    uint32_t                            bIsWritable;
 
     // If the patching location does not start at bit 0 then the value to be patched needs to be shifted
     uint32_t                            shiftAmount;
@@ -632,7 +642,8 @@ MOS_STATUS Mhw_SurfaceFormatToType(
 
 MOS_STATUS Mhw_SendGenericPrologCmd(
     PMOS_COMMAND_BUFFER         pCmdBuffer,
-    PMHW_GENERIC_PROLOG_PARAMS  pParams);
+    PMHW_GENERIC_PROLOG_PARAMS  pParams,
+    MHW_MI_MMIOREGISTERS       *pMmioReg = nullptr);
 
 MOS_STATUS Mhw_SetNearestModeTable(
     int32_t         *iCoefs,
@@ -646,7 +657,8 @@ MOS_STATUS Mhw_CalcPolyphaseTablesY(
     MOS_FORMAT      srcFmt,
     float           fHPStrength,
     bool            bUse8x8Filter,
-    uint32_t        dwHwPhase);
+    uint32_t        dwHwPhase,
+    float           fLanczosT);
 
 MOS_STATUS Mhw_CalcPolyphaseTablesUV(
     int32_t  *piCoefs,
