@@ -104,7 +104,9 @@ typedef enum _MEDIA_EVENT
     EVENT_DDE_CB_SEND_DATA,
     EVENT_DDE_MESSAGE,              //! event for debug message
     EVENT_OCA_ERROR,                //! event for OCA error.
-    EVENT_DATA_DUMP                 //! event for debug data dump
+    EVENT_DATA_DUMP,                //! event for debug data dump
+    EVENT_HECI_OBJ,                 //! event for heci duplicate handle
+    EVENT_PLAT_INFO                 //! event for static platform info
 } MEDIA_EVENT;
 
 typedef enum _MEDIA_EVENT_TYPE
