@@ -86,6 +86,204 @@
 //!
 #define VPHAL_CURBE_BLOCK_ALIGN_G7      32
 
+// Defined DP used FC kernel for computation.
+struct MEDIA_DP_FC_STATIC_DATA
+{
+     // DWORD 0 - GRF R1.0
+    union
+    {
+        // CSC
+        struct
+        {
+            uint32_t       CscConstantC0               : 16;
+            uint32_t       CscConstantC1               : 16;
+        };
+
+        uint32_t       Value;
+    } DW0;
+
+    // DWORD 1 - GRF R1.1
+    union
+    {
+        // CSC
+        struct
+        {
+            uint32_t       CscConstantC2               : 16;
+            uint32_t       CscConstantC3               : 16;
+        };
+
+        uint32_t       Value;
+    } DW1;
+
+    // DWORD 2 - GRF R1.2
+    union
+    {
+        // CSC
+        struct
+        {
+            uint32_t       CscConstantC4               : 16;
+            uint32_t       CscConstantC5               : 16;
+        };
+
+        uint32_t       Value;
+    } DW2;
+
+    // DWORD 3 - GRF R1.3
+    union
+    {
+        // CSC
+        struct
+        {
+            uint32_t       CscConstantC6               : 16;
+            uint32_t       CscConstantC7               : 16;
+        };
+
+        uint32_t       Value;
+    } DW3;
+
+    // DWORD 4 - GRF R1.4
+    union
+    {
+        // CSC
+        struct
+        {
+            uint32_t       CscConstantC8               : 16;
+            uint32_t       CscConstantC9               : 16;
+        };
+
+        uint32_t       Value;
+    } DW4;
+
+    // DWORD 5 - GRF R1.5
+    union
+    {
+        // CSC
+        struct
+        {
+            uint32_t       CscConstantC10              : 16;
+            uint32_t       CscConstantC11              : 16;
+        };
+
+        uint32_t       Value;
+    } DW5;
+
+    // DWORD 6 - GRF R1.6
+    union
+    {
+        // Dataport-based rotation
+        struct
+        {
+            uint32_t       InputPictureWidth           : 16;
+            uint32_t       InputPictureHeight          : 16;
+        };
+
+        uint32_t       Value;
+    } DW6;
+
+    // DWORD 7 - GRF R1.7 distWidth and distHeight
+    union
+    {
+        struct
+        {
+            uint32_t       DestinationRectangleWidth   : 16;
+            uint32_t       DestinationRectangleHeight  : 16;
+        };
+
+        uint32_t       Value;
+    } DW7;
+
+    // DWORD 8 - GRF R1.8
+    union
+    {
+        struct
+        {
+            uint32_t       RotationChromaSitingFlag;
+        };
+
+        uint32_t       Value;
+    } DW8;
+
+    // DWORD 9 - GRF R1.9  input DeltaX
+    union
+    {
+        struct
+        {
+            float       HorizontalScalingStepRatioLayer0;
+        };
+
+        uint32_t       Value;
+    } DW9;
+
+    // DWORD 10 - GRF R2.0  input DeltaY
+    union
+    {
+        struct
+        {
+            float       VerticalScalingStepRatioLayer0;
+        };
+
+        uint32_t       Value;
+    } DW10;
+
+    // DWORD 11 - GRF R2.1  input orignin x
+    union
+    {
+        struct
+        {
+            float       HorizontalFrameOriginLayer0;
+        };
+
+        uint32_t       Value;
+    } DW11;
+
+    // DWORD 12 - GRF R2.2  input orignin Y
+    union
+    {
+        struct
+        {
+            float       VerticalFrameOriginLayer0;
+        };
+
+        uint32_t       Value;
+    } DW12;
+
+    // DWORD13  - GRF R2.3  topleft[2]
+    union
+    {
+        struct
+        {
+            uint32_t       DestXTopLeftLayer0  : 16;
+            uint32_t       DestYTopLeftLayer0  : 16;
+        };
+
+        uint32_t       Value;
+    } DW13;
+
+    // DWORD14  - GRF R2.4  bottomRight
+    union
+    {
+        struct
+        {
+            uint32_t       DestXBottomRightLayer0  : 16;
+            uint32_t       DestYBottomRightLayer0  : 16;
+        };
+
+        uint32_t       Value;
+    } DW14;
+
+    // DWORD15  - GRF R2.4  waflag and dstpitch
+    union
+    {
+        struct
+        {
+            uint32_t       waFlag                 : 16;
+            uint32_t       StatisticsSurfacePitch : 16;
+        };
+
+        uint32_t       Value;
+    } DW15;
+
+};
 // Defined in Inline parameter computation
 struct MEDIA_WALKER_KA2_STATIC_DATA
 {
