@@ -34,6 +34,7 @@
 #include "codechal_decode_vc1_g11.h"
 #include "codechal_secure_decode_interface.h"
 #include "mhw_vdbox_mfx_g11_X.h"
+#include "hal_oca_interface.h"
 
 MOS_STATUS CodechalDecodeVc1G11::AllocateStandard(
     CodechalSetting *          settings)
@@ -74,12 +75,12 @@ MOS_STATUS CodechalDecodeVc1G11::SetGpuCtxCreatOption(
     {
         m_gpuCtxCreatOpt = MOS_New(MOS_GPUCTX_CREATOPTIONS_ENHANCED);
 
-        CODECHAL_DECODE_CHK_STATUS_RETURN(CodecHalDecodeSinglePipeVE_ConstructParmsForGpuCtxCreation(    
+        CODECHAL_DECODE_CHK_STATUS_RETURN(CodecHalDecodeSinglePipeVE_ConstructParmsForGpuCtxCreation(
             m_veState,
             (PMOS_GPUCTX_CREATOPTIONS_ENHANCED)m_gpuCtxCreatOpt,
             false));
-    }
-        
+        m_videoContext = MOS_GPU_CONTEXT_VIDEO; // Move functionality to CodecHalDecodeMapGpuNodeToGpuContex
+    } 
     return eStatus;
 }
 
@@ -173,6 +174,9 @@ MOS_STATUS CodechalDecodeVc1G11::DecodeStateLevel()
     MOS_COMMAND_BUFFER  cmdBuffer;
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnGetCommandBuffer(m_osInterface, &cmdBuffer, 0));
 
+    auto mmioRegisters = m_hwInterface->GetMfxInterface()->GetMmioRegisters(m_vdboxIndex);
+    HalOcaInterface::On1stLevelBBStart(cmdBuffer, *m_osInterface->pOsContext, m_osInterface->CurrentGpuContextHandle, *m_miInterface, *mmioRegisters);
+
     if (m_olpNeeded)
     {
         CODECHAL_DECODE_CHK_STATUS_RETURN(SendPrologWithFrameTracking(&cmdBuffer, false));
@@ -257,12 +261,18 @@ MOS_STATUS CodechalDecodeVc1G11::DecodeStateLevel()
 
     pipeBufAddrParams.pDecodedReconParam = &surfaceParams;
     pipeBufAddrParams.pRawSurfParam = nullptr;
+
+#ifdef _MMC_SUPPORTED
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->SetPipeBufAddr(&pipeBufAddrParams, &cmdBuffer));
+#endif
+
     pipeBufAddrParams.pDecodedReconParam = nullptr;
 
+#ifdef _MMC_SUPPORTED
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->CheckReferenceList(&pipeBufAddrParams));
 
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->SetRefrenceSync(m_disableDecodeSyncLock, m_disableLockForTranscode));
+#endif
 
     CODECHAL_DEBUG_TOOL(
         for (int i = 0; i < CODEC_MAX_NUM_REF_FRAME_NON_AVC; i++)
@@ -457,6 +467,33 @@ MOS_STATUS CodechalDecodeVc1G11::DecodePrimitiveLevelVLD()
             int32_t lLength = slc->slice_data_size >> 3;
             int32_t lOffset = slc->macroblock_offset >> 3;
 
+            CodechalResLock ResourceLock(m_osInterface, &m_resDataBuffer);
+            auto buf = (uint8_t*)ResourceLock.Lock(CodechalResLock::readOnly);
+            buf += slc->slice_data_offset;
+            if (lOffset > 3 && buf != nullptr &&
+                m_vc1PicParams->sequence_fields.AdvancedProfileFlag)
+            {
+                int i = 0;
+                int j = 0;
+                for (i = 0, j = 0; i < lOffset - 1; i++, j++)
+                {
+                    if (!buf[j] && !buf[j + 1] && buf[j + 2] == 3 && buf[j + 3] < 4)
+                    {
+                        i++, j += 2;
+                    }
+                }
+                if (i == lOffset - 1)
+                {
+                    if (!buf[j] && !buf[j + 1] && buf[j + 2] == 3 && buf[j + 3] < 4)
+                    {
+                        buf[j + 2] = 0;
+                        j++;
+                    }
+                    j++;
+                }
+                lOffset = (8 * j + slc->macroblock_offset % 8)>>3;
+            }
+
             // Check that the slice data does not overrun the bitstream buffer size
             if (((uintptr_t)(slc->slice_data_offset) + lLength) > m_dataSize)
             {
@@ -531,6 +568,7 @@ MOS_STATUS CodechalDecodeVc1G11::DecodePrimitiveLevelVLD()
                         lOffset = CODECHAL_DECODE_VC1_STUFFING_BYTES - 1;
                         lLength += CODECHAL_DECODE_VC1_STUFFING_BYTES;
                         slc->macroblock_offset += CODECHAL_DECODE_VC1_STUFFING_BYTES << 3;
+                        slc->macroblock_offset &= (~0x7); // Clear bit offset of first MB for short format
                     }
                 }
             }
@@ -685,6 +723,13 @@ submit:
         m_huCCopyInUse = false;
     }
 
+    if (m_osInterface->osCpInterface->IsHMEnabled())
+    {
+        HalOcaInterface::DumpCpParam(cmdBuffer, *m_osInterface->pOsContext, m_osInterface->osCpInterface->GetOcaDumper());
+    }
+
+    HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface->pOsContext);
+
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSubmitCommandBuffer(m_osInterface, &cmdBuffer, m_videoContextUsesNullHw));
 
     CODECHAL_DEBUG_TOOL(
@@ -992,6 +1037,13 @@ MOS_STATUS CodechalDecodeVc1G11::DecodePrimitiveLevelIT()
         m_huCCopyInUse = false;
     }
 
+    if (m_osInterface->osCpInterface->IsHMEnabled())
+    {
+        HalOcaInterface::DumpCpParam(cmdBuffer, *m_osInterface->pOsContext, m_osInterface->osCpInterface->GetOcaDumper());
+    }
+
+    HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface->pOsContext);
+
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSubmitCommandBuffer(m_osInterface, &cmdBuffer, m_videoContextUsesNullHw));
 
     CODECHAL_DEBUG_TOOL(
@@ -1060,7 +1112,7 @@ MOS_STATUS CodechalDecodeVc1G11::HandleSkipFrame()
     MHW_GENERIC_PROLOG_PARAMS           genericPrologParams;
     MOS_SURFACE                         srcSurface;
     uint8_t                             fwdRefIdx;
-    uint16_t                            surfaceHeight;
+    uint32_t                            surfaceSize;
     MOS_SYNC_PARAMS                     syncParams;
     MOS_STATUS                          eStatus = MOS_STATUS_SUCCESS;
 
@@ -1073,19 +1125,24 @@ MOS_STATUS CodechalDecodeVc1G11::HandleSkipFrame()
     srcSurface.OsResource = m_vc1RefList[fwdRefIdx]->resRefPic;
     CODECHAL_DECODE_CHK_STATUS_RETURN(CodecHalGetResourceInfo(m_osInterface, &srcSurface));
 
+#ifdef _MMC_SUPPORTED
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->SetSurfaceMmcMode(&m_destSurface, &srcSurface));
+#endif
 
-    surfaceHeight = MOS_ALIGN_CEIL(((srcSurface.dwHeight * 3) / 2), MOS_YTILE_H_ALIGNMENT);
+        surfaceSize = ((srcSurface.OsResource.pGmmResInfo->GetArraySize()) > 1) ?
+            ((uint32_t)(srcSurface.OsResource.pGmmResInfo->GetQPitchPlanar(GMM_PLANE_Y) *
+                        srcSurface.OsResource.pGmmResInfo->GetRenderPitch())) :
+            (uint32_t)(srcSurface.OsResource.pGmmResInfo->GetSizeMainSurface());
 
     if (m_hwInterface->m_noHuC)
     {
         CodechalDataCopyParams dataCopyParams;
         MOS_ZeroMemory(&dataCopyParams, sizeof(CodechalDataCopyParams));
         dataCopyParams.srcResource = &srcSurface.OsResource;
-        dataCopyParams.srcSize     = surfaceHeight * m_destSurface.dwPitch;
+        dataCopyParams.srcSize     = surfaceSize;
         dataCopyParams.srcOffset = srcSurface.dwOffset;
         dataCopyParams.dstResource = &m_destSurface.OsResource;
-        dataCopyParams.dstSize     = surfaceHeight * m_destSurface.dwPitch;
+        dataCopyParams.dstSize     = surfaceSize;
         dataCopyParams.dstOffset   = m_destSurface.dwOffset;
 
         CODECHAL_DECODE_CHK_STATUS_RETURN(m_hwInterface->CopyDataSourceWithDrv(&dataCopyParams));
@@ -1118,7 +1175,7 @@ MOS_STATUS CodechalDecodeVc1G11::HandleSkipFrame()
             &cmdBuffer,                             // pCmdBuffer
             &srcSurface.OsResource,                 // presSrc
             &m_destSurface.OsResource,              // presDst
-            surfaceHeight * m_destSurface.dwPitch,  // u32CopyLength
+            surfaceSize,                            // u32CopyLength
             srcSurface.dwOffset,                    // u32CopyInputOffset
             m_destSurface.dwOffset));               // u32CopyOutputOffset
 
@@ -1203,7 +1260,9 @@ MOS_STATUS CodechalDecodeVc1G11::PerformVc1Olp()
 
     CodecHalGetResourceInfo(m_osInterface, &m_deblockSurface);  // DstSurface
 
+#ifdef _MMC_SUPPORTED
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->DisableSurfaceMmcState(&m_deblockSurface));
+#endif
 
     CODECHAL_DECODE_CHK_STATUS_RETURN(stateHeapInterface->pfnRequestSshSpaceForCmdBuf(
         stateHeapInterface,
@@ -1271,7 +1330,9 @@ MOS_STATUS CodechalDecodeVc1G11::PerformVc1Olp()
     surfaceParamsSrc.dwYOffset[MHW_U_PLANE] =
         (m_destSurface.UPlaneOffset.iYOffset % MOS_YTILE_H_ALIGNMENT);
 
+#ifdef _MMC_SUPPORTED
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->GetSurfaceMmcState(surfaceParamsSrc.psSurface));
+#endif
 
     MHW_RCS_SURFACE_PARAMS surfaceParamsDst;
     MOS_ZeroMemory(&surfaceParamsDst, sizeof(surfaceParamsDst));
