@@ -97,6 +97,7 @@ GMM_RESOURCE_FORMAT GraphicsResourceSpecific::ConvertMosFmtToGmmFmt(MOS_FORMAT f
         case Format_BGRP        : return GMM_FORMAT_BGRP_TYPE;
         case Format_R8U         : return GMM_FORMAT_R8_UINT_TYPE;
         case Format_R16U        : return GMM_FORMAT_R16_UINT_TYPE;
+        case Format_R16F        : return GMM_FORMAT_R16_FLOAT_TYPE;
         case Format_P010        : return GMM_FORMAT_P010_TYPE;
         case Format_P016        : return GMM_FORMAT_P016_TYPE;
         case Format_Y216        : return GMM_FORMAT_Y216_TYPE;
@@ -106,6 +107,8 @@ GMM_RESOURCE_FORMAT GraphicsResourceSpecific::ConvertMosFmtToGmmFmt(MOS_FORMAT f
         case Format_Y210        : return GMM_FORMAT_Y210_TYPE;
         case Format_Y410        : return GMM_FORMAT_Y410_TYPE;
         case Format_R10G10B10A2 : return GMM_FORMAT_R10G10B10A2_UNORM_TYPE;
+        case Format_A16B16G16R16F: return GMM_FORMAT_R16G16B16A16_FLOAT;
+        case Format_R32G32B32A32F: return GMM_FORMAT_R32G32B32A32_FLOAT;
         default                 : return GMM_FORMAT_INVALID;
     }
 }
@@ -145,6 +148,7 @@ MOS_STATUS GraphicsResourceSpecific::Allocate(OsContext* osContextPtr, CreatePar
     switch (params.m_type)
     {
         case MOS_GFXRES_BUFFER:
+        case MOS_GFXRES_SCRATCH:
           gmmParams.Type = RESOURCE_BUFFER;
           gmmParams.Flags.Gpu.State = true;
           alignedHeight = 1;
@@ -181,14 +185,20 @@ MOS_STATUS GraphicsResourceSpecific::Allocate(OsContext* osContextPtr, CreatePar
     switch (tileformat)
     {
         case MOS_TILE_Y:
-            gmmParams.Flags.Gpu.MMC       = params.m_isCompressed;
+            gmmParams.Flags.Gpu.MMC       = params.m_isCompressible;
             tileFormatLinux               = I915_TILING_Y;
-            if (params.m_isCompressed && pOsContextSpecific->GetAuxTableMgr())
+            if (params.m_isCompressible && MEDIA_IS_SKU(pOsContextSpecific->GetSkuTable(), FtrE2ECompression))
             {
+                gmmParams.Flags.Gpu.MMC = true;
                 gmmParams.Flags.Info.MediaCompressed = 1;
                 gmmParams.Flags.Gpu.CCS = 1;
-                gmmParams.Flags.Gpu.UnifiedAuxSurface = 1;
                 gmmParams.Flags.Gpu.RenderTarget = 1;
+                gmmParams.Flags.Gpu.UnifiedAuxSurface = 1;
+
+                if(MEDIA_IS_SKU(pOsContextSpecific->GetSkuTable(), FtrFlatPhysCCS))
+                {
+                    gmmParams.Flags.Gpu.UnifiedAuxSurface = 0;
+                }
             }
             break;
         case MOS_TILE_X:
@@ -311,6 +321,8 @@ MOS_STATUS GraphicsResourceSpecific::Allocate(OsContext* osContextPtr, CreatePar
         m_depth     = MOS_MAX(1, gmmResourceInfoPtr->GetBaseDepth());
         m_size      = (uint32_t)gmmResourceInfoPtr->GetSizeSurface();
         m_tileType  = tileformat;
+        m_tileModeGMM           = (MOS_TILE_MODE_GMM)gmmResourceInfoPtr->GetTileModeSurfaceState();
+        m_isGMMTileEnabled      = true;
 
         m_compressible    = gmmParams.Flags.Gpu.MMC ?
             (gmmResourceInfoPtr->GetMmcHint(0) == GMM_MMC_HINT_ON) : false;
@@ -389,6 +401,8 @@ MOS_STATUS GraphicsResourceSpecific::ConvertToMosResource(MOS_RESOURCE* pMosReso
     pMosResource->iPitch   = m_pitch;
     pMosResource->iDepth   = m_depth;
     pMosResource->TileType = m_tileType;
+    pMosResource->TileModeGMM = m_tileModeGMM;
+    pMosResource->bGMMTileEnabled = m_isGMMTileEnabled;
     pMosResource->iCount   = 0;
     pMosResource->pData    = m_pData;
     pMosResource->bufname  = m_name.c_str();
@@ -429,9 +443,12 @@ void* GraphicsResourceSpecific::Lock(OsContext* osContextPtr, LockParams& params
     {
         // Do decompression for a compressed surface before lock
         const auto pGmmResInfo = m_gmmResInfo;
-         MOS_OS_ASSERT(pGmmResInfo);
+        MOS_OS_ASSERT(pGmmResInfo);
+        GMM_RESOURCE_FLAG GmmFlags = pGmmResInfo->GetResFlags();
+        
         if (!params.m_noDecompress &&
-             pGmmResInfo->IsMediaMemoryCompressed(0))
+            (((GmmFlags.Gpu.MMC || GmmFlags.Gpu.CCS) && GmmFlags.Info.MediaCompressed) ||
+             pGmmResInfo->IsMediaMemoryCompressed(0)))
         {
             if ((pOsContextSpecific->m_mediaMemDecompState == nullptr) ||
                 (pOsContextSpecific->m_memoryDecompress    == nullptr))
@@ -453,16 +470,6 @@ void* GraphicsResourceSpecific::Lock(OsContext* osContextPtr, LockParams& params
             }
             else
             {
-#ifdef ANDROID
-                if (m_tileType != MOS_TILE_LINEAR ||params.m_uncached)
-                {
-                    mos_gem_bo_map_gtt(boPtr);
-                }
-                else
-                {
-                    mos_bo_map(boPtr, ( OSKM_LOCKFLAG_WRITEONLY & params.m_writeRequest ));
-                }
-#else
                 if (m_tileType != MOS_TILE_LINEAR && !params.m_tileAsTiled)
                 {
                     if (pOsContextSpecific->UseSwSwizzling())
@@ -501,7 +508,6 @@ void* GraphicsResourceSpecific::Lock(OsContext* osContextPtr, LockParams& params
                     mos_bo_map(boPtr, ( OSKM_LOCKFLAG_WRITEONLY & params.m_writeRequest ));
                     m_mmapOperation = MOS_MMAP_OPERATION_MMAP;
                 }
-#endif
             }
             m_mapped = true;
             m_pData  = m_systemShadow ? m_systemShadow : (uint8_t *)boPtr->virt;
@@ -543,17 +549,6 @@ MOS_STATUS GraphicsResourceSpecific::Unlock(OsContext* osContextPtr)
            }
            else
            {
-#ifdef ANDROID
-
-               if (m_tileType == MOS_TILE_LINEAR)
-               {
-                   mos_bo_unmap(boPtr);
-               }
-               else
-               {
-                   mos_gem_bo_unmap_gtt(boPtr);
-               }
-#else
                if (m_systemShadow)
                {
                    int32_t flags = pOsContextSpecific->GetTileYFlag() ? 0 : 1;
@@ -580,7 +575,6 @@ MOS_STATUS GraphicsResourceSpecific::Unlock(OsContext* osContextPtr)
                         MOS_OS_ASSERTMESSAGE("Invalid mmap operation type");
                         break;
                }
-#endif
             }
 
             m_mapped           = false;
